# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from nfe.pysped.xml_sped import TagCaracter, TagInteiro, TagDecimal, TagDataHoraUTC
from nfe.mdfe.manual_300.modalFerroviario import ModalFerro
from nfe.mdfe.manual_300.modalAquaviario import ModalAquav
from nfe.mdfe.manual_300.modalRodoviario import ModalRodo
from nfe.mdfe.manual_300.modalAereo import ModalAereo
from nfe.pysped.xml_sped import ABERTURA, Signature
from nfe.mdfe.base import XMLMDFe, NAMESPACE_MDFE
from nfe.mdfe.manual_300 import *
import os

DIRNAME = os.path.dirname(__file__)


class InfMunCarrega(XMLMDFe):
    """Informacoes dos municipios de carregamento"""
    def __init__(self):
        super(InfMunCarrega, self).__init__()
        self.cMunCarrega = TagCaracter(nome=u'cMunCarrega', tamanho=[7, 7], raiz=u'//infMunCarrega')
        self.xMunCarrega = TagCaracter(
            nome=u'xMunCarrega', tamanho=[2, 60], raiz=u'//infMunCarrega')

    @property
    def xml(self):
        xml = u'<infMunCarrega>'
        xml += self.cMunCarrega.xml
        xml += self.xMunCarrega.xml
        xml += u'</infMunCarrega>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cMunCarrega.xml = arquivo
        self.xMunCarrega.xml = arquivo


class InfPercurso(XMLMDFe):
    """Informacoes do percurso do MDF-e"""
    def __init__(self):
        super(InfPercurso, self).__init__()
        self.ufPer = TagCaracter(nome=u'UFPer', tamanho=[2, 2], raiz=u'//infPercurso')

    @property
    def xml(self):
        if not self.ufPer.valor:  # Nao obrigatorio
            return u''
        xml = u'<infPercurso>'
        xml += self.ufPer.xml
        xml += u'</infPercurso>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.ufPer.xml = arquivo


class Ide(XMLMDFe):
    """Identificacao do MDF-e"""
    def __init__(self):
        super(Ide, self).__init__()
        self.cUF = TagInteiro(nome=u'cUF', tamanho=[2, 2], raiz=u'//ide')
        self.tpAmb = TagInteiro(nome=u'tpAmb', tamanho=[1, 1], raiz=u'//ide')
        self.tpEmit = TagInteiro(nome=u'tpEmit', tamanho=[1, 1], raiz=u'//ide')
        self.tpTransp = TagInteiro(
            nome=u'tpTransp', tamanho=[1, 1], raiz=u'//ide', obrigatorio=False)
        self.mod = TagInteiro(nome=u'mod', tamanho=[2, 2], raiz=u'//ide', valor=58)
        self.serie = TagInteiro(nome=u'serie', tamanho=[1, 3], raiz=u'//ide')
        self.nMDF = TagInteiro(nome=u'nMDF', tamanho=[1, 9], raiz=u'//ide')
        self.cMDF = TagCaracter(nome=u'cMDF', tamanho=[8, 8], raiz=u'//ide')
        self.cDV = TagCaracter(nome=u'cDV', tamanho=[1, 1], raiz=u'//ide')
        self.modal = TagInteiro(nome=u'modal', tamanho=[1, 1], raiz=u'//ide')
        self.dhEmi = TagDataHoraUTC(nome=u'dhEmi', raiz=u'//ide')
        self.tpEmis = TagInteiro(nome=u'tpEmis', tamanho=[1, 1], raiz=u'//ide')
        self.procEmi = TagCaracter(nome=u'procEmi', tamanho=[1, 1], raiz=u'ide')
        self.verProc = TagCaracter(nome=u'verProc', tamanho=[1, 20], raiz=u'ide')
        self.ufIni = TagCaracter(nome=u'UFIni', tamanho=[2, 2], raiz=u'//ide')
        self.ufFim = TagCaracter(nome=u'UFFim', tamanho=[2, 2], raiz=u'//ide')
        self.infMunCarrega = []  # Maximo = 50
        self.infPercurso = []  # Nao obrigatorio - Maximo = 25
        self.dhIniViagem = TagDataHoraUTC(nome=u'dhIniViagem', raiz=u'//ide', obrigatorio=False)
        self.indCanalVerde = TagInteiro(
            nome=u'indCanalVerde', tamanho=[1, 1], raiz=u'//ide', obrigatorio=False)
        self.indCarregaPosterior = TagInteiro(
            nome=u'indCarregaPosterior', tamanho=[1, 1], raiz=u'ide', obrigatorio=False)

    @property
    def xml(self):
        xml = u'<ide>'
        xml += self.cUF.xml
        xml += self.tpAmb.xml
        xml += self.tpEmit.xml
        xml += self.tpTransp.xml
        xml += self.mod.xml
        xml += self.serie.xml
        xml += self.nMDF.xml
        xml += self.cMDF.xml
        xml += self.cDV.xml
        xml += self.modal.xml
        xml += self.dhEmi.xml
        xml += self.tpEmis.xml
        xml += self.procEmi.xml
        xml += self.verProc.xml
        xml += self.ufIni.xml
        xml += self.ufFim.xml
        for imc in self.infMunCarrega[:50] or [InfMunCarrega()]:  # De 1 a 50 ocorrencias
            xml += imc.xml
        for ip in self.infPercurso[:25]:  # Nao obrigatorio - Maximo de 25 ocorrencias
            xml += ip.xml
        xml += self.dhIniViagem.xml
        xml += self.indCanalVerde.xml
        xml += self.indCarregaPosterior.xml
        xml += u'</ide>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.cUF.xml = arquivo
            self.tpAmb.xml = arquivo
            self.tpEmit.xml = arquivo
            self.tpTransp.xml = arquivo
            self.mod.xml = arquivo
            self.serie.xml = arquivo
            self.nMDF.xml = arquivo
            self.cMDF.xml = arquivo
            self.cDV.xml = arquivo
            self.modal.xml = arquivo
            self.dhEmi.xml = arquivo
            self.tpEmis.xml = arquivo
            self.procEmi.xml = arquivo
            self.verProc.xml = arquivo
            self.ufIni.xml = arquivo
            self.ufFim.xml = arquivo
            self.infMunCarrega = self.le_grupo(u'//ide/infMunCarrega', InfMunCarrega)
            self.infPercurso = self.le_grupo(u'//ide/infPercurso', InfPercurso)
            self.dhIniViagem.xml = arquivo
            self.indCanalVerde.xml = arquivo
            self.indCarregaPosterior.xml = arquivo


class EnderEmit(XMLMDFe):
    """Endereco do emitente"""
    def __init__(self):
        super(EnderEmit, self).__init__()
        self.xLgr = TagCaracter(nome=u'xLgr', tamanho=[2, 60], raiz=u'//enderEmit')
        self.nro = TagCaracter(nome=u'nro', tamanho=[1, 60], raiz=u'//enderEmit')
        self.xCpl = TagCaracter(
            nome=u'xCpl', tamanho=[1, 60], raiz=u'//enderEmit', obrigatorio=False)
        self.xBairro = TagCaracter(nome=u'xBairro', tamanho=[2, 60], raiz=u'//enderEmit')
        self.cMun = TagCaracter(nome=u'cMun', tamanho=[7, 7], raiz=u'//enderEmit')
        self.xMun = TagCaracter(nome=u'xMun', tamanho=[2, 60], raiz=u'//enderEmit')
        self.cep = TagInteiro(
            nome=u'CEP', tamanho=[8, 8], raiz=u'//enderEmit', obrigatorio=False)
        self.uf = TagCaracter(nome=u'UF', tamanho=[2, 2], raiz=u'//enderEmit')
        self.fone = TagInteiro(
            nome=u'fone', tamanho=[7, 12], raiz=u'//enderEmit', obrigatorio=False)
        self.email = TagCaracter(
            nome=u'email', tamanho=[1, 60], raiz=u'//enderEmit', obrigatorio=False)

    @property
    def xml(self):
        xml = u'<enderEmit>'
        xml += self.xLgr.xml
        xml += self.nro.xml
        xml += self.xCpl.xml
        xml += self.xBairro.xml
        xml += self.cMun.xml
        xml += self.xMun.xml
        xml += self.cep.xml
        xml += self.uf.xml
        xml += self.fone.xml
        xml += self.email.xml
        xml += u'</enderEmit>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.xLgr.xml = arquivo
        self.nro.xml = arquivo
        self.xCpl.xml = arquivo
        self.xBairro.xml = arquivo
        self.cMun.xml = arquivo
        self.xMun.xml = arquivo
        self.cep.xml = arquivo
        self.uf.xml = arquivo
        self.fone.xml = arquivo
        self.email.xml = arquivo


class Emit(XMLMDFe):
    """Identificacao do emitente do MDF-e"""
    def __init__(self):
        super(Emit, self).__init__()
        self.cnpj = TagCaracter(nome=u'CNPJ', tamanho=[14, 14], raiz=u'//emit')
        self.ie = TagCaracter(nome=u'IE', tamanho=[2, 14], raiz=u'//emit')
        self.xNome = TagCaracter(nome=u'xNome', tamanho=[2, 60], raiz=u'//emit')
        self.xFant = TagCaracter(nome=u'xFant', tamanho=[1, 60], raiz=u'//emit', obrigatorio=False)
        self.enderEmit = EnderEmit()

    @property
    def xml(self):
        xml = u'<emit>'
        xml += self.cnpj.xml
        xml += self.ie.xml
        xml += self.xNome.xml
        xml += self.xFant.xml
        xml += self.enderEmit.xml
        xml += u'</emit>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cnpj.xml = arquivo
        self.ie.xml = arquivo
        self.xNome.xml = arquivo
        self.xFant.xml = arquivo
        self.enderEmit.xml = arquivo


class InfResp(XMLMDFe):
    """Informacoes do responsavel pelo seguro da carga"""
    def __init__(self):
        super(InfResp, self).__init__()
        self.respSeg = TagInteiro(nome=u'respSeg', tamanho=[1, 1], raiz=u'//infResp')
        self.cnpj = TagInteiro(nome=u'CNPJ', tamanho=[14, 14], raiz=u'//infResp')
        self.cpf = TagInteiro(nome=u'CPF', tamanho=[11, 11], raiz=u'//infResp')

    @property
    def xml(self):
        xml = u'<infResp>'
        xml += self.respSeg.xml
        xml += self.cnpj.xml if self.cnpj.valor else self.cpf.xml
        xml += u'</infResp>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.respSeg.xml = arquivo
        self.cnpj.xml = arquivo
        self.cpf.xml = arquivo


class InfSeg(XMLMDFe):
    """Informacoes da seguradora"""
    def __init__(self):
        super(InfSeg, self).__init__()
        self.xSeg = TagCaracter(nome=u'xSeg', tamanho=[1, 30], raiz=u'//infSeg')
        self.cnpj = TagInteiro(nome=u'CNPJ', tamanho=[14, 14], raiz=u'//infSeg')

    @property
    def xml(self):
        if not all([self.xSeg.valor, self.cnpj.valor]):  # Nao obrigatorio
            return u''
        xml = u'<infSeg>'
        xml += self.xSeg.xml
        xml += self.cnpj.xml
        xml += u'</infSeg>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.xSeg.xml = arquivo
        self.cnpj.xml = arquivo


class NAver(XMLMDFe):
    """Numero da averbacao"""
    def __init__(self):
        super(NAver, self).__init__()
        self.nAver = TagCaracter(
            nome=u'nAver', tamanho=[1, 40], raiz=u'//nAver', obrigatorio=False)

    @property
    def xml(self):
        xml = self.nAver.xml

        return xml

    @ xml.setter
    def xml(self, arquivo):
        self.nAver.xml = arquivo


class Seg(XMLMDFe):
    """Informacoes de seguranca da carga"""
    def __init__(self):
        super(Seg, self).__init__()
        self.infResp = InfResp()
        self.infSeg = InfSeg()  # Nao obrigatorio
        self.nApol = TagCaracter(
            nome=u'nApol', tamanho=[1, 20], raiz=u'//seg', obrigatorio=False)
        self.nAver = []

    @property
    def xml(self):
        if not self.nApol.valor:  # Nao obrigatorio
            return u''
        xml = u'<seg>'
        xml += self.infResp.xml
        xml += self.infSeg.xml
        xml += self.nApol.xml
        for na in self.nAver:
            xml += na.xml
        xml += u'</seg>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.infResp.xml = arquivo
            self.infSeg.xml = arquivo
            self.nApol.xml = arquivo
            self.nAver = self.le_grupo(u'//seg/nAver', NAver)


class Lacres(XMLMDFe):
    """Lacres do MDF-e"""
    def __init__(self):
        super(Lacres, self).__init__()
        self.nLacre = TagCaracter(nome=u'nLacre', tamanho=[1, 60], raiz=u'//lacres')

    @property
    def xml(self):
        if not self.nLacre.valor:  # Nao obrigatorio
            return u''
        xml = u'<lacres>'
        xml += self.nLacre.xml
        xml += u'</lacres>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.nLacre.xml = arquivo


class AutXML(XMLMDFe):
    """Autorizados para download do XML do MFD-e"""
    def __init__(self):
        super(AutXML, self).__init__()
        self.cnpj = TagCaracter(nome=u'CNPJ', tamanho=[14, 14], raiz=u'//autXML')
        self.cpf = TagCaracter(nome=u'CPF', tamanho=[11, 11], raiz=u'//autXML')

    @property
    def xml(self):
        if not any([self.cnpj.valor, self.cpf.valor]):  # Nao obrigatorio
            return u''
        xml = u'<autXML>'
        xml += self.cnpj.xml if self.cnpj.valor else self.cpf.xml
        xml += u'</autXML>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cnpj.xml = arquivo
        self.cpf.xml = arquivo


class InfModal(XMLMDFe):
    """Informacoes do modal: rodoviario, aereo, ferroviario ou aquaviario"""
    def __init__(self):
        super(InfModal, self).__init__()
        self.versao = TagDecimal(
            nome=u'infModal', tamanho=[1, 4, 1], decimais=[0, 2, 2], propriedade=u'versao',
            raiz=u'//infModal', valor=u'3.00')
        self.modalRodo = ModalRodo()
        self.modalAereo = ModalAereo()
        self.modalAquav = ModalAquav()
        self.modalFerro = ModalFerro()

    @property
    def xml(self):
        xml = u'<infModal versaoModal="%s">' % self.versao.valor
        if self.modalRodo.veicTracao.placa.valor:
            xml += self.modalRodo.xml
        elif self.modalAereo.nac.valor:
            xml += self.modalAereo.xml
        elif self.modalAquav.irin.valor:
            xml += self.modalAquav.xml
        elif self.modalFerro.trem.xPref.valor:
            xml += self.modalFerro.xml
        xml += u'</infModal>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.versao.xml = arquivo
        self.modalRodo.xml = arquivo
        self.modalAereo.xml = arquivo
        self.modalFerro.xml = arquivo
        self.modalAquav.xml = arquivo


class LacUnidTransp(XMLMDFe):
    """Lacres das unidades de transporte"""
    def __init__(self):
        super(LacUnidTransp, self).__init__()
        self.nLacre = TagCaracter(nome=u'nLacre', tamanho=[1, 20], raiz=u'//lacUnidTransp')

    @property
    def xml(self):
        xml = u'<lacUnidTransp>'
        xml += self.nLacre.xml
        xml += u'<lacUnidTransp>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.nLacre.xml = arquivo


class LacUnidCarga(XMLMDFe):
    """Lacres das unidades de carga"""
    def __init__(self):
        super(LacUnidCarga, self).__init__()
        self.nLacre = TagCaracter(nome=u'nLacre', tamanho=[1, 20], raiz=u'//lacUnidCarga')

    @property
    def xml(self):
        xml = u'<lacUnidCarga>'
        xml += self.nLacre.xml
        xml += u'</lacUnidCarga>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.nLacre.xml = arquivo


class InfUnidCarga(XMLMDFe):
    """Informacoes das unidades de carga (containers/ULD/outros)"""
    def __init__(self):
        super(InfUnidCarga, self).__init__()
        self.tpUnidCarga = TagInteiro(
            nome=u'tpUnidCarga', tamanho=[1, 1], raiz=u'//infUnidCarga')
        self.idUnidCarga = TagCaracter(nome=u'idUnidCarga', tamanho=[1, 20], raiz=u'//infUnidCarga')
        self.lacUnidCarga = []
        self.qtdRat = TagDecimal(
            nome=u'qtdRat', tamanho=[1, 5, 1], decimais=[0, 2, 2], raiz=u'//infUnidCarga')

    @property
    def xml(self):
        xml = u'<infUnidCarga>'
        xml += self.tpUnidCarga.xml
        xml += self.idUnidCarga.xml
        for luc in self.lacUnidCarga:
            xml += luc.xml
        xml += self.qtdRat.xml
        xml += u'</infUnidCarga>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.tpUnidCarga.xml = arquivo
            self.idUnidCarga.xml = arquivo
            self.lacUnidCarga = self.le_grupo(u'//infUnidCarga/lacUnidCarga', LacUnidCarga)
            self.qtdRat.xml = arquivo


class InfUnidTransp(XMLMDFe):
    """Informacoes das unidades de transporte (carreta/reboque/vagao)"""
    def __init__(self):
        super(InfUnidTransp, self).__init__()
        self.tpUnidTransp = TagInteiro(
            nome=u'tpUnidTransp', tamanho=[1, 1], raiz=u'//infUnidTransp')
        self.idUnidTransp = TagCaracter(
            nome=u'idUnidTransp', tamanho=[1, 20], raiz=u'//infUnidTransp')
        self.lacUnidTransp = []
        self.infUnidCarga = []
        self.qtdRat = TagDecimal(
            nome=u'qtdRat', tamanho=[1, 5, 1], decimais=[0, 2, 2], raiz=u'//infUnidTransp')

    @property
    def xml(self):
        xml = u'<infUnidTransp>'
        xml += self.tpUnidTransp.xml
        xml += self.idUnidTransp.xml
        for lut in self.lacUnidTransp:
            xml += lut.xml
        for iuc in self.infUnidCarga:
            xml += iuc.xml
        xml += self.qtdRat.xml
        xml += u'</infUnidTransp>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.tpUnidTransp.xml = arquivo
            self.idUnidTransp.xml = arquivo
            self.lacUnidTransp = self.le_grupo(u'//infCTe/lacUnidTransp', LacUnidTransp)
            self.infUnidCarga = self.le_grupo(u'//infCTe/infUnidCarga', InfUnidCarga)
            self.qtdRat.xml = arquivo


class Peri(XMLMDFe):
    """Produtos classificados pela ONU/UN como perigosos"""
    def __init__(self):
        super(Peri, self).__init__()
        self.nONU = TagCaracter(nome=u'nONU', tamanho=[4, 4], raiz=u'//peri')
        self.xNomeAE = TagCaracter(
            nome=u'xNomeAE', tamanho=[1, 150], raiz=u'//peri', obrigatorio=False)
        self.xClaRisco = TagCaracter(
            nome=u'xClaRisco', tamanho=[1, 40], raiz=u'//peri', obrigatorio=False)
        self.grEmb = TagCaracter(
            nome=u'grEmb', tamanho=[1, 6], raiz=u'//peri', obrigatorio=False)
        self.qTotProd = TagCaracter(nome=u'qTotProd', tamanho=[1, 20], raiz=u'//peri')
        self.qVolTipo = TagCaracter(
            nome=u'qVolTipo', tamanho=[1, 60], raiz=u'//peri', obrigatorio=False)

    @property
    def xml(self):
        if not self.nONU.valor:  # Nao obrigatorio
            return u''
        xml = u'<peri>'
        xml += self.nONU.xml
        xml += self.xNomeAE.xml
        xml += self.xClaRisco.xml
        xml += self.grEmb.xml
        xml += self.qTotProd.xml
        xml += self.qVolTipo.xml
        xml += u'</peri>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.nONU.xml = arquivo
        self.xNomeAE.xml = arquivo
        self.xClaRisco.xml = arquivo
        self.grEmb.xml = arquivo
        self.qTotProd.xml = arquivo
        self.qVolTipo.xml = arquivo


class InfEntregaParcial(XMLMDFe):
    """Informacoes da entrega parcial da carga"""
    def __init__(self):
        super(InfEntregaParcial, self).__init__()
        self.qtdTotal = TagDecimal(
            nome=u'qtdTotal', tamanho=[1, 15, 1], decimais=[0, 4, 4], raiz=u'//infEntregaParcial')
        self.qtdParcial = TagDecimal(
            nome=u'qtdParcial', tamanho=[1, 15, 1], decimais=[0, 4, 4], raiz=u'//infEntregaParcial')

    @property
    def xml(self):
        if not self.qtdParcial.valor:  # Nao obrigatorio
            return u''
        xml = u'<infEntregaParcial>'
        xml += self.qtdTotal.xml
        xml += self.qtdParcial.xml
        xml += u'</infEntregaParcial>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.qtdTotal.xml = arquivo
        self.qtdParcial.xml = arquivo


class InfCTe(XMLMDFe):
    """Conhecimento de Transporte - Quando prestador de servico de transporte"""
    def __init__(self):
        super(InfCTe, self).__init__()
        self.chCTe = TagInteiro(nome=u'chCTe', tamanho=[44, 44], raiz=u'//infCTe')
        self.segCodBarra = TagInteiro(
            nome=u'SegCodBarra', tamanho=[36, 36], raiz=u'//infCTe', obrigatorio=False)
        self.indReentrega = TagInteiro(
            nome=u'indReentrega', tamanho=[1, 1], raiz=u'//infCTe', obrigatorio=False)
        self.infUnidTransp = []  # Nao obrigatorio
        self.peri = []  # Nao obrigatorio
        self.infEntregaParcial = InfEntregaParcial()

    @property
    def xml(self):
        if not self.chCTe.valor:  # Nao obrigatorio
            return u''
        xml = u'<infCTe>'
        xml += self.chCTe.xml
        xml += self.segCodBarra.xml
        xml += self.indReentrega.xml
        for iut in self.infUnidTransp:
            xml += iut.xml
        for p in self.peri:
            xml += p.xml
        xml += self.infEntregaParcial.xml
        xml += u'</infCTe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.chCTe.xml = arquivo
            self.segCodBarra.xml = arquivo
            self.indReentrega.xml = arquivo
            self.infUnidTransp = self.le_grupo(u'//infCTe/infUnidTransp', InfUnidTransp)
            self.peri = self.le_grupo(u'//infCTe/peri', Peri)
            self.infEntregaParcial.xml = arquivo


class InfNFe(XMLMDFe):
    """Nota Fiscal Eletronica"""
    def __init__(self):
        super(InfNFe, self).__init__()
        self.chNFe = TagCaracter(nome=u'chNFe', tamanho=[44, 44], raiz=u'//infNFe')
        self.segCodBarra = TagInteiro(
            nome=u'SegCodBarra', tamanho=[36, 36], raiz=u'//infNFe', obrigatorio=False)
        self.indReentrega = TagInteiro(
            nome=u'indReentrega', tamanho=[1, 1], raiz=u'//infNFe', obrigatorio=False)
        self.infUnidTransp = []  # Nao obrigatorio
        self.peri = []  # Nao obrigatorio

    @property
    def xml(self):
        if not self.chNFe.valor:  # Nao obrigatorio
            return u''
        xml = u'<infNFe>'
        xml += self.chNFe.xml
        xml += self.segCodBarra.xml
        xml += self.indReentrega.xml
        for iut in self.infUnidTransp:
            xml += iut.xml
        for p in self.peri:
            xml += p.xml
        xml += u'</infNFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.chNFe.xml = arquivo
            self.segCodBarra.xml = arquivo
            self.indReentrega.xml = arquivo
            self.infUnidTransp = self.le_grupo(u'//infNFe/infUnidTransp', InfUnidTransp)
            self.peri = self.le_grupo(u'//infNFe/peri', Peri)


class InfMDFeTransp(XMLMDFe):
    """Manifesto Eletronico de Documentos Fiscais - Somente para modal aquaviario (vide MOC)"""
    def __init__(self):
        super(InfMDFeTransp, self).__init__()
        self.chMDFe = TagInteiro(nome=u'chMDFe', tamanho=[44, 44], raiz=u'//infMDFeTransp')
        self.indReentrega = TagInteiro(
            nome=u'indReentrega', tamanho=[1, 1], raiz=u'//infMDFeTransp', obrigatorio=False)
        self.infUnidTransp = []  # Nao obrigatorio
        self.peri = []  # Nao obrigatorio

    @property
    def xml(self):
        if not self.chMDFe.valor:  # Nao obrigatorio
            return u''
        xml = u'<infMDFeTransp>'
        xml += self.chMDFe.xml
        xml += self.indReentrega.xml
        for iut in self.infUnidTransp:
            xml += iut.xml
        for p in self.peri:
            xml += p.xml
        xml += u'</infMDFeTransp>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.chMDFe.xml = arquivo
            self.indReentrega.xml = arquivo
            self.infUnidTransp = self.le_grupo(u'//infMDFeTransp/infUnidTransp', InfUnidTransp)
            self.peri = self.le_grupo(u'//infMDFeTransp/peri', Peri)


class InfMunDescarga(XMLMDFe):
    """Informacoes dos municipios de descarregamento"""
    def __init__(self):
        super(InfMunDescarga, self).__init__()
        self.cMunDescarga = TagCaracter(
            nome=u'cMunDescarga', tamanho=[7, 7], raiz=u'//infMunDescarga')
        self.xMunDescarga = TagCaracter(
            nome=u'xMunDescarga', tamanho=[2, 60], raiz=u'//infMunDescarga')
        self.infCTe = []  # Nao obrigatorio - Maximo 10000
        self.infNFe = []  # Nao obrigatorio - Maximo 10000
        self.infMDFeTransp = []  # Nao obrigatorio - Maximo 10000

    @property
    def xml(self):
        xml = u'<infMunDescarga>'
        xml += self.cMunDescarga.xml
        xml += self.xMunDescarga.xml
        for cte in self.infCTe:
            xml += cte.xml
        for nfe in self.infNFe:
            xml += nfe.xml
        for mdf in self.infMDFeTransp:
            xml += mdf.xml
        xml += u'</infMunDescarga>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.cMunDescarga.xml = arquivo
            self.xMunDescarga.xml = arquivo
            self.infCTe = self.le_grupo(u'//infMunDescarga/infCTe', InfCTe)
            self.infNFe = self.le_grupo(u'//infMunDescarga/infNFe', InfNFe)
            self.infMDFeTransp = self.le_grupo(u'//infMunDescarga/infMDFeTransp', InfMDFeTransp)


class InfDoc(XMLMDFe):
    """Informacoes dos documentos fiscais vinculados ao manifesto"""
    def __init__(self):
        super(InfDoc, self).__init__()
        self.infMunDescarga = []  # Maximo 100

    @property
    def xml(self):
        xml = u'<infDoc>'
        for imd in self.infMunDescarga or [InfMunDescarga()]:  # De 1 a 100 ocorrencias
            xml += imd.xml
        xml += u'</infDoc>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.infMunDescarga = self.le_grupo(u'//infDoc/infMunDescarga', InfMunDescarga)


class Tot(XMLMDFe):
    """Totalizadores da carga transportada e seus documentos fiscais"""
    def __init__(self):
        super(Tot, self).__init__()
        self.qCTe = TagInteiro(nome=u'qTCe', tamanho=[1, 6], raiz=u'//tot', obrigatorio=False)
        self.qNFe = TagInteiro(nome=u'qNFe', tamanho=[1, 6], raiz=u'//tot', obrigatorio=False)
        self.qMDFe = TagInteiro(nome=u'qMDFe', tamanho=[1, 6], raiz=u'//tot', obrigatorio=False)
        self.vCarga = TagDecimal(
            nome=u'vCarga', tamanho=[1, 15, 1], decimais=[0, 2, 2], raiz=u'//tot')
        self.cUnid = TagCaracter(nome=u'cUnid', tamanho=[2, 2], raiz=u'//tot')
        self.qCarga = TagDecimal(
            nome=u'qCarga', tamanho=[1, 15, 4], decimais=[0, 4, 4], raiz=u'//tot')

    @property
    def xml(self):
        xml = u'<tot>'
        xml += self.qCTe.xml
        xml += self.qNFe.xml
        xml += self.qMDFe.xml
        xml += self.vCarga.xml
        xml += self.cUnid.xml
        xml += self.qCarga.xml
        xml += u'</tot>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.qCTe.xml = arquivo
        self.qNFe.xml = arquivo
        self.qMDFe.xml = arquivo
        self.vCarga.xml = arquivo
        self.cUnid.xml = arquivo
        self.qCarga.xml = arquivo


class InfAdic(XMLMDFe):
    """Informacoes Adicionais"""
    def __init__(self):
        super(InfAdic, self).__init__()
        self.infAdFisco = TagCaracter(nome=u'infAdFisco', tamanho=[1, 2000], raiz=u'//infAdic')
        self.infCpl = TagCaracter(nome=u'infCpl', tamanho=[1, 5000], raiz=u'//infAdic')

    @property
    def xml(self):
        if not all([self.infAdFisco.valor, self.infCpl.valor]):  # Nao obrigatorio
            return u''
        xml = u'<infAdic>'
        xml += self.infAdFisco.xml
        xml += self.infCpl.xml
        xml += u'</infAdic>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.infAdFisco.xml = arquivo
        self.infCpl.xml = arquivo


class InfRespTec(XMLMDFe):
    """Informacoes do responsavel tecnico pela emissao do DF-e"""
    def __init__(self):
        super(InfRespTec, self).__init__()
        self.cnpj = TagInteiro(
            nome=u'CNPJ', tamanho=[14, 14], raiz=u'//infRespTec', obrigatorio=False)
        self.xContato = TagCaracter(nome=u'xContato', tamanho=[2, 60], raiz=u'//infRespTec')
        self.email = TagCaracter(
            nome=u'email', tamanho=[6, 60], raiz=u'//infRespTec')
        self.fone = TagInteiro(nome=u'fone', tamanho=[7, 12], raiz=u'//infRespTec')
        self.idCSRT = TagInteiro(
            nome=u'idCSRT', tamanho=[3, 3], raiz=u'//infRespTec', obrigatorio=False)
        self.hashCSRT = TagCaracter(
            nome=u'hashCSRT', tamanho=[28, 28], raiz=u'//infRespTec', obrigatorio=False)

    @property
    def xml(self):
        if not self.cnpj.valor:  # Nao obrigatorio
            return u''
        xml = u'<infRespTec>'
        xml += self.cnpj.xml
        xml += self.xContato.xml
        xml += self.email.xml
        xml += self.fone.xml
        xml += self.idCSRT.xml
        xml += self.hashCSRT.xml
        xml += u'</infRespTec>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cnpj.xml = arquivo
        self.xContato.xml = arquivo
        self.email.xml = arquivo
        self.fone.xml = arquivo
        self.idCSRT.xml = arquivo
        self.hashCSRT.xml = arquivo


class InfMDFe(XMLMDFe):
    """Informacoes do MDF-e"""
    def __init__(self):
        super(InfMDFe, self).__init__()
        self.Id = TagCaracter(nome=u'infMDFe', tamnho=[48, 48], propriedade=u'Id', raiz=u'/')
        self.versao = TagDecimal(
            nome=u'infMDFe', tamanho=[1, 4, 1], decimais=[0, 2, 2], propriedade=u'versao',
            raiz=u'/', namespace=NAMESPACE_MDFE, valor=u'3.00')
        self.ide = Ide()
        self.emit = Emit()
        self.infModal = InfModal()
        self.infDoc = InfDoc()
        self.seg = []  # Nao obrigatorio
        self.tot = Tot()
        self.lacres = []  # Nao obrigatorio
        self.autXML = []  # Nao obrigatorio - Maximo = 10
        self.infAdic = InfAdic()  # Nao obrigatorio
        self.infRespTec = InfRespTec()  # Nao obrigatorio

    @property
    def xml(self):
        xml = u'<infMDFe Id="%s" versao="%s">' % (self.Id.valor, self.versao.valor)
        xml += self.ide.xml
        xml += self.emit.xml
        xml += self.infModal.xml
        xml += self.infDoc.xml
        for s in self.seg:
            xml += s.xml
        xml += self.tot.xml
        for l in self.lacres:
            xml += l.xml
        for a in self.autXML:
            xml += a.xml
        xml += self.infAdic.xml
        xml += self.infRespTec.xml
        xml += u'</infMDFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.Id.xml = arquivo
            self.versao.xml = arquivo
            self.ide.xml = arquivo
            self.emit.xml = arquivo
            self.infModal.xml = arquivo
            self.infDoc.xml = arquivo
            self.seg = self.le_grupo(u'//infMDFe/seg', Seg)
            self.tot.xml = arquivo
            self.lacres = self.le_grupo(u'//infMDFe/lacres', Lacres)
            self.autXML = self.le_grupo(u'//infMDFe/autXML', AutXML)
            self.infAdic.xml = arquivo
            self.infRespTec.xml = arquivo


class InfMDFeSupl(XMLMDFe):
    """Informações suplementares do MDF-e"""
    def __init__(self):
        super(InfMDFeSupl, self).__init__()
        self.qrCodMDFe = TagCaracter(nome=u'qrCodMDFe', tamanho=[50, 500], raiz=u'//infMDFeSupl')

    @property
    def xml(self):
        xml = u'<infMDFeSupl>'
        xml += self.qrCodMDFe.xml
        xml += u'</infMDFeSupl>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.qrCodMDFe.xml = arquivo


class MDFe(XMLMDFe):
    """Manifesto Eletronico de Documentos Fiscais"""
    def __init__(self):
        super(MDFe, self).__init__()
        self.infMDFe = InfMDFe()
        self.infMDFeSupl = InfMDFeSupl()
        self.signature = Signature()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'mdfe_v3.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += u'<MDFe xmlns="http://www.portalfiscal.inf.br/mdfe">'
        xml += self.infMDFe.xml
        xml += self.infMDFeSupl.xml
        self.signature.URI = u'#' + self.infMDFe.Id.valor
        xml += self.signature.xml
        xml += u'</MDFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.infMDFe.xml = arquivo
            self.infMDFeSupl.xml = arquivo
            self.signature.xml = self._le_noh(u'//MDFe/sig:Signature')

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
