# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from nfe.pysped.xml_sped import TagCaracter
from nfe.mdfe.base import XMLMDFe, NAMESPACE_MDFE
from nfe.mdfe.manual_300 import *
import os

DIRNAME = os.path.dirname(__file__)


class Condutor(XMLMDFe):
    """Informacoes do condutor do veiculo."""
    def __init__(self):
        super(Condutor, self).__init__()
        self.xNome = TagCaracter(nome=u'xNome', tamanho=[2, 50], raiz=u'//condutor')
        self.cpf = TagCaracter(nome=u'CPF', tamanho=[11, 11], raiz=u'//condutor')

    @property
    def xml(self):
        xml = u'<condutor>'
        xml += self.xNome.xml
        xml += self.cpf.xml
        xml += u'</condutor>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.xNome.xml = arquivo
        self.cpf.xml = arquivo


class EvIncCondutorMDFe(XMLMDFe):
    """Leiaute especifico do evento de inclusao de condutor no MDF-e Rodoviario."""
    def __init__(self):
        super(EvIncCondutorMDFe, self).__init__()
        self.descEvento = TagCaracter(
            nome=u'descEvento', tamanho=[17, 17], raiz=u'/',
            valor=u'Inclusao Condutor')
        self.condutor = Condutor()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'evIncCondutorMDFe_v3.00.xsd'

    @property
    def xml(self):
        xml = u'<evIncCondutorMDFe xmlns="%s">' % NAMESPACE_MDFE
        xml += u'<descEvento>Inclusao Condutor</descEvento>'  # self.descEvento.xml
        xml += self.condutor.xml
        xml += u'</evIncCondutorMDFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.descEvento.xml = arquivo
        self.condutor.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
