# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from nfe.pysped.xml_sped import TagDecimal, TagInteiro, TagCaracter
from nfe.mdfe.base import XMLMDFe, NAMESPACE_MDFE
from nfe.mdfe.manual_300 import *
import os

DIRNAME = os.path.dirname(__file__)


class InfMDFe(XMLMDFe):
    """Grupo com relação de MDF-e nao encerrados."""
    def __init__(self):
        super(InfMDFe, self).__init__()
        self.chMDFe = TagCaracter(nome=u'chMDFe', tamanho=[44, 44], raiz=u'//infMDFe')
        self.nProt = TagCaracter(nome=u'nProt', tamanho=[15, 15], raiz=u'//infMDFe')

    @property
    def xml(self):
        xml = u'<infMDFe>'
        xml += self.chMDFe.xml
        xml += self.nProt.xml
        xml += u'</infMDFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        self.chMDFe.xml = arquivo
        self.nProt.xml = arquivo


class RetConsMDFeNaoEnc(XMLMDFe):
    """Leiaute da retorno da consulta MDF-e nao encerrados."""
    def __init__(self):
        super(RetConsMDFeNaoEnc, self).__init__()
        self.versao = TagDecimal(
            nome=u'retConsMDFeNaoEnc', tamanho=[1, 4, 1], decimais=[0, 2, 2], propriedade=u'versao',
            raiz=u'/', namespace=NAMESPACE_MDFE, valor=u'3.00')
        self.tpAmb = TagInteiro(nome=u'tpAmb', tamanho=[1, 1], raiz=u'//retConsMDFeNaoEnc')
        self.verAplic = TagCaracter(nome=u'verAplic', tamanho=[1, 20], raiz=u'//retConsMDFeNaoEnc')
        self.cStat = TagCaracter(nome=u'cStat', tamanho=[3, 3], raiz=u'//retConsMDFeNaoEnc')
        self.xMotivo = TagCaracter(nome=u'xMotivo', tamanho=[1, 255], raiz=u'//retConsMDFeNaoEnc')
        self.cUF = TagInteiro(nome=u'cUF', tamanho=[2, 2], raiz=u'//retConsMDFeNaoEnc')
        self.infMDFe = []
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'retConsMDFeNaoEnc_v3.00.xsd'

    @property
    def xml(self):
        xml = u'<retConsMDFeNaoEnc xmlns="%s" versao="%s">' % (NAMESPACE_MDFE, self.versao.valor)
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        for i in self.infMDFe:
            xml += i.xml
        xml += u'</retConsMDFeNaoEnc>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.infMDFe = self.le_grupo(u'//infMDFe', InfMDFe)

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
