# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from nfe.pysped.xml_sped import TagCaracter, TagInteiro, TagDecimal, ABERTURA
from nfe.mdfe.manual_300.procEventoMDFe import ProcEventoMDFe
from nfe.mdfe.manual_300.retConsReciMDFe import ProtMDFe
from nfe.mdfe.base import XMLMDFe, NAMESPACE_MDFE
from nfe.mdfe.manual_300 import *
import os

DIRNAME = os.path.dirname(__file__)


class RetConsSitMDFe(XMLMDFe):
    """Mensagem de consulta da situacao atual do MDF-e."""
    def __init__(self):
        super(RetConsSitMDFe, self).__init__()
        self.versao = TagDecimal(
            nome=u'retConsSitMDFe', tamanho=[1, 4, 1], decimais=[0, 2, 2], propriedade=u'versao',
            raiz=u'/', namespace=NAMESPACE_MDFE, valor=u'3.00')
        self.tpAmb = TagInteiro(nome=u'tpAmb', tamanho=[1, 1], raiz=u'//retConsSitMDFe')
        self.verAplic = TagCaracter(nome=u'verAplic', tamanho=[1, 20], raiz=u'//retConsSitMDFe')
        self.cStat = TagCaracter(nome=u'cStat', tamanho=[3, 3], raiz=u'//retConsSitMDFe')
        self.xMotivo = TagCaracter(nome=u'xMotivo', tamanho=[1, 255], raiz=u'//retConsSitMDFe')
        self.protMDFe = ProtMDFe()
        self.procEventoMDFe = []
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'retConsSitMDFe_v3.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += u'<retConsSitMDFe xmlns="%s" versao="%s">' % (NAMESPACE_MDFE, self.versao.valor)
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.protMDFe.xml
        for p in self.procEventoMDFe:
            xml += p.xml
        xml += u'</retConsSitMDFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.protMDFe.xml = arquivo
            self.procEventoMDFe = self.le_grupo(u'//procEventoMDFe', ProcEventoMDFe)


# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
