# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from reportlab.lib.enums import TA_LEFT, TA_CENTER, TA_RIGHT
from geraldo import ReportBand, ObjectValue, Label, Image
from reportlab.lib.pagesizes import A5, landscape
from reportlab.lib.colors import HexColor
from reportlab.lib.units import cm
from StringIO import StringIO
import qrcode
import os

DIRNAME = os.path.dirname(__file__)

# Margens e tamanhos padronizados
PAGE_SIZE = A5
PORTRAIT = PAGE_SIZE
LANDSCAPE = landscape(PAGE_SIZE)
MARGIN_TOP = 0.5*cm
MARGIN_BOTTOM = 0.5*cm
MARGIN_LEFT = 0.5*cm
MARGIN_RIGHT = 0.5*cm
WIDTH_PORTRAIT = PORTRAIT[0] - MARGIN_LEFT - MARGIN_LEFT
WIDTH_LANDSCAPE = LANDSCAPE[0] - MARGIN_LEFT - MARGIN_RIGHT

# Fontes
FONTS = {
    u'DejaVu Sans Mono': (
        (u'DejaVu Sans Mono', DIRNAME + u'/fonts/DejaVuSansMono.ttf', False, False),
        (u'DejaVu Sans Mono Bold', DIRNAME + u'/fonts/DejaVuSansMono-Bold.ttf', True, False),
        (u'DejaVu Sans Mono Italic', DIRNAME + u'/fonts/DejaVuSansMono-Oblique.ttf', False, True),
        (u'DejaVu Sans Mono Bold Italic', DIRNAME + u'/fonts/DejaVuSansMono-BoldOblique.ttf', True,
         True),
    )
}

# Estilos
NORMAL = u'DejaVu Sans Mono'
BOLD = NORMAL + u' Bold'
OBLIQUE = NORMAL + u' Italic'
BOLD_OBLIQUE = NORMAL + u' Bold Italic'
SIZE_6 = 6
SIZE_7 = SIZE_6 + 1
SIZE_8 = SIZE_6 + 2
SIZE_9 = SIZE_6 + 3
SIZE_10 = SIZE_6 + 4
SIZE_105 = SIZE_10 + .5
SIZE_11 = SIZE_10 + 1
SIZE_12 = SIZE_6 * 2
SIZE_13 = SIZE_6 * 2 + 1
SIZE_18 = SIZE_6 * 3
SIZE_40 = SIZE_8 * 5

# Cores
RED1 = HexColor(0xff9393)
GRAY1 = HexColor(0x939393)

SILVER = HexColor(0xC0C0C0)   # rgb(192, 192, 192)
GRAY = HexColor(0x808080)     # rgb(128, 128, 128)
BLACK = HexColor(0x000000)    # rgb(0, 0, 0)
RED = HexColor(0xff0000)      # rgb(255, 0, 0)
MAROON = HexColor(0x800000)   # rgb(128, 0, 0)
YELLOW = HexColor(0xffff00)   # rgb(255, 255, 0)
OLIVE = HexColor(0x808000)    # rgb(128, 128, 0)
LIME = HexColor(0x00ff00)     # rgb(0, 255, 0)
GREEN = HexColor(0x008000)    # rgb(0, 128, 0)
AQUA = HexColor(0x00ffff)     # rgb(0, 255, 255)
TEAL = HexColor(0x008080)     # rgb(0, 128, 128)
BLUE = HexColor(0x0000ff)     # rgb(0, 0, 255)
NAVY = HexColor(0x000080)     # rgb(0, 0, 128)
FUCHSIA = HexColor(0xff00ff)  # rgb(255, 0, 255)
PURPLE = HexColor(0x800080)   # rgb(128, 0, 128)


# Padroes
DEFAULT = dict(fontName=NORMAL, fontSize=SIZE_6, alignment=TA_LEFT)
DEFAULT_RIGHT = dict(fontName=NORMAL, fontSize=SIZE_6, alignment=TA_RIGHT)
DEFAULT_CENTER = dict(fontName=NORMAL, fontSize=SIZE_6, alignment=TA_CENTER)
DEFAULT_BOLD = dict(fontName=BOLD, fontSize=SIZE_6, alignment=TA_LEFT)
DEFAULT_BOLD_RIGHT = dict(fontName=BOLD, fontSize=SIZE_6, alignment=TA_RIGHT)
DEFAULT_BOLD_CENTER = dict(fontName=BOLD, fontSize=SIZE_6, alignment=TA_CENTER)
ITEM = dict(fontName=NORMAL, fontSize=SIZE_6, alignment=TA_LEFT, leading=6)
ITEM_CENTER = dict(fontName=NORMAL, fontSize=SIZE_6, alignment=TA_CENTER, leading=6)
ITEM_BOLD = dict(fontName=BOLD, fontSize=SIZE_6, alignment=TA_LEFT, leading=6)
ITEM_RIGHT = dict(fontName=NORMAL, fontSize=SIZE_6, alignment=TA_RIGHT, leading=6)
ITEM_BOLD_RIGHT = dict(fontName=BOLD, fontSize=SIZE_6, alignment=TA_RIGHT, leading=6)
ITEM_BOLD_CENTER = dict(fontName=BOLD, fontSize=SIZE_6, alignment=TA_CENTER, leading=6)
OCCURRENCE = dict(fontName=BOLD, fontSize=SIZE_9, alignment=TA_LEFT, textColor=RED1)
OCCURRENCE_CENTER = dict(fontName=BOLD, fontSize=SIZE_9, alignment=TA_CENTER, textColor=RED1)
OCCURRENCE_6B = dict(fontName=BOLD, fontSize=SIZE_6, alignment=TA_LEFT, textColor=RED1)
OCCURRENCE_13 = dict(fontName=BOLD, fontSize=SIZE_13, alignment=TA_LEFT, textColor=RED1)
OCCURRENCE_8B = dict(fontName=BOLD, fontSize=SIZE_8, alignment=TA_LEFT, textColor=BLACK)
OCCURRENCE_8B_RIGHT = dict(fontName=BOLD, fontSize=SIZE_8, alignment=TA_RIGHT, textColor=BLACK)
OCCURRENCE_CENTER_13 = dict(fontName=BOLD, fontSize=SIZE_13, alignment=TA_CENTER, textColor=RED1)
WATER_MARK = dict(fontName=BOLD, fontSize=SIZE_18, alignment=TA_CENTER, textColor=GRAY1)
OBSERVATION = dict(fontName=BOLD, fontSize=SIZE_40, alignment=TA_CENTER, textColor=RED1)


class LabelDANFE(Label):
    def __init__(self):
        super(LabelDANFE, self).__init__()
        self.height = .1*cm
        self.padding_top = 0
        self.padding_bottom = 0
        self.padding_left = 0
        self.padding_right = 0


class FieldDANFE(ObjectValue):
    def __init__(self):
        super(FieldDANFE, self).__init__()
        self.height = .1*cm
        self.padding_top = 0
        self.padding_bottom = 0
        self.padding_left = 0
        self.padding_right = 0


class ImageDANFE(Image):
    def __init__(self):
        super(ImageDANFE, self).__init__()
        self.width = 2.5*cm
        self.height = 2.5*cm
        self.left = 0
        self.top = 0


class BandDANFE(ReportBand):
    def __init__(self):
        super(BandDANFE, self).__init__()

    @staticmethod
    def _add_label(text, top, left, width, height=None):
        lbl = LabelDANFE()
        lbl.text = text or u''
        lbl.top = top*cm
        lbl.left = left*cm
        lbl.width = width*cm
        lbl.height = height and height*cm or lbl.height

        return lbl

    @staticmethod
    def _add_field(attr_name, top, left, width, height=None):
        fld = FieldDANFE()
        fld.attribute_name = attr_name
        fld.top = top*cm
        fld.left = left*cm
        fld.width = width*cm
        fld.height = height and height*cm or fld.height

        return fld

    @staticmethod
    def _add_image(filename, top, left, width, height=None):
        img = ImageDANFE()
        img.filename = filename.len and filename or None
        img.top = top*cm
        img.left = left*cm
        img.width = width*cm
        img.height = height and height*cm or img.height

        return img

    def add_label(self, text, top, left, width, height=None, style=None, visible=True):
        lbl = self._add_label(text, top, left, width, height)
        lbl.style = style or DEFAULT
        lbl.visible = bool(visible)
        self.elements.append(lbl)

        return lbl

    def add_field(self, attr_name, top, left, width, height=None, style=None, visible=True):
        fld = self._add_field(attr_name, top, left, width, height)
        fld.style = style or DEFAULT
        fld.visible = bool(visible)
        self.elements.append(fld)

        return fld

    def add_image(self, filename, top, left, width, height=None, visible=True):
        img = self._add_image(filename, top, left, width, height)
        img.visible = bool(visible)
        self.elements.append(img)

        return img

    def add_qrcode(self, value, top, left, width=3, height=3):
        qr = qrcode.QRCode(version=1, error_correction=qrcode.constants.ERROR_CORRECT_L)
        qr.add_data(value)
        qr.make()
        img = qr.make_image()
        qr_img = StringIO()
        img.save(qr_img)
        qrc = self._add_image(qr_img, top, left, width, height)
        self.elements.append(qrc)


LOGO = """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"""
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
