# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from nfe.pysped.xml_sped import *
from nfe.nfe_400.manual_600 import nfe_400


class InfNFeSupl(XMLNFe):
    def __init__(self):
        super(InfNFeSupl, self).__init__()
        self.qrCode = TagCaracter(nome=u'qrCode', codigo=u'ZX02', tamanho=[100, 600],
                                  raiz=u'//NFe/infNFeSupl')
        self.urlChave = TagCaracter(nome=u'urlChave', codigo=u'ZX03', tamanho=[21, 85],
                                    raiz=u'//NFe/infNFeSupl')

    @property
    def xml(self):
        if not self.qrCode.valor:
            return u''
        xml = XMLNFe.get_xml(self)
        xml += u'<infNFeSupl>'
        xml += self.qrCode.xml
        xml += self.urlChave.xml
        xml += u'</infNFeSupl>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.qrCode.xml = arquivo
            self.urlChave.xml = arquivo


class TagCSTICMS(nfe_400.TagCSTICMS):
    def __init__(self, *args, **kwargs):
        super(TagCSTICMS, self).__init__(*args, **kwargs)

    @property
    def valor(self):
        return super(TagCSTICMS, self).get_valor()

    @valor.setter
    def valor(self, novo_valor):
        super(TagCSTICMS, self).set_valor(novo_valor)
        if self.grupo_icms:
            # Definimos todas as tags como nao obrigatorias
            self.grupo_icms.vICMSSubstituto.obrigatorio = False

            # Por seguranca, zeramos os valores das tags do grupo ICMS ao redefinirmos o codigo da
            # situacao tributaria
            self.grupo_icms.vICMSSubstituto.valor = u'0.00'
            self.grupo_icms.pST.valor = u'0.00'
            self.grupo_icms.vICMSSTRet.valor = u'0.00'

            # Para cada codigo de situacao tributaria, redefinimos a raiz e a obrigatoriedade das
            # tags do grupo de ICMS
            if self.valor == u'60':
                self.grupo_icms.vICMSSubstituto.obrigatorio = False
            self.grupo_icms.vBCFCPSTRet.obrigatorio = False
            self.grupo_icms.pFCPSTRet.obrigatorio = False
            self.grupo_icms.vFCPSTRet.obrigatorio = False

            # Redefine a raiz para todas as tags do grupo ICMS
            self.grupo_icms.vICMSSubstituto.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.orig.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.motDesICMS.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vICMSDeson.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vBCSTRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vICMSSTRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vBCSTDest.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vICMSSTDest.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.UFST.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pBCOp.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vBCFCP.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pFCP.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vFCP.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vBCFCPST.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pFCPST.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vFCPST.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pST.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vICMSSubstituto.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vBCFCPSTRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pFCPSTRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vFCPSTRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vICMSOp.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pDif.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vICMSDif.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.qBCMonoRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.adRemICMSRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vICMSMonoRet.raiz = self.grupo_icms.raiz_tag


class TagCSOSN(nfe_400.TagCSOSN):
    def __init__(self, *args, **kwargs):
        super(TagCSOSN, self).__init__(*args, **kwargs)

    @property
    def valor(self):
        return super(TagCSOSN, self).get_valor()

    @valor.setter
    def valor(self, novo_valor):
        super(TagCSOSN, self).set_valor(novo_valor)
        if self.grupo_icms:
            # Para cada codigo de situacao tributaria, redefinimos a obrigatoriedade das tags do
            # grupo de ICMS
            if self.valor == u'102':
                self.grupo_icms.vFCPSTRet.obrigatorio = False
            if self.valor in (u'201', u'202', u'900'):
                self.grupo_icms.pMVAST.obrigatorio = False
                self.grupo_icms.pRedBCST.obrigatorio = False
            if self.valor == u'500':
                self.grupo_icms.vICMSSubstituto.obrigatorio = False
                self.grupo_icms.vICMSSubstituto.valor = u'0.00'
                self.grupo_icms.pST.valor = u'0.00'
                self.grupo_icms.vICMSSTRet.valor = u'0.00'
                self.grupo_icms.vBCFCPSTRet.obrigatorio = False
                self.grupo_icms.pFCPSTRet.obrigatorio = False
                self.grupo_icms.vFCPSTRet.obrigatorio = False

            # Redefine a raiz para todas as tags do grupo ICMS
            self.grupo_icms.vICMSSubstituto.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pMVAST.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pRedBCST.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vFCPSTRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pST.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vICMSSTRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.vBCFCPSTRet.raiz = self.grupo_icms.raiz_tag
            self.grupo_icms.pFCPSTRet.raiz = self.grupo_icms.raiz_tag

class ICMS(nfe_400.ICMS):
    def __init__(self):
        super(ICMS, self).__init__()
        self.CST = TagCSTICMS()
        self.CST.grupo_icms = self
        self.CSOSN = TagCSOSN()
        self.CSOSN.grupo_icms = self

    @property
    def xml(self):
        xml = u'<ICMS><' + self.nome_tag + u'>'
        xml += self.orig.xml
        if self.regime_tributario != 1:
            xml += self.CST.xml
            if self.CST.valor == u'00':
                xml += self.modBC.xml
                xml += self.vBC.xml
                xml += self.pICMS.xml
                xml += self.vICMS.xml
                if self.vFCP.valor:
                    xml += self.pFCP.xml
                    xml += self.vFCP.xml
            elif self.CST.valor == u'10':  # Vale para ICMSPart - Partilha
                xml += self.modBC.xml
                xml += self.vBC.xml
                if self.partilha:
                    xml += self.pRedBC.xml
                xml += self.pICMS.xml
                xml += self.vICMS.xml
                xml += self.modBCST.xml
                if self.modBCST.valor == 4:
                    xml += self.pMVAST.xml
                xml += self.pRedBCST.xml
                xml += self.vBCST.xml
                xml += self.pICMSST.xml
                xml += self.vICMSST.xml
                if self.vFCPST.valor:
                    xml += self.vBCFCP.xml
                    xml += self.pFCPST.xml
                    xml += self.vFCPST.xml
            elif self.CST.valor == u'20':
                xml += self.modBC.xml
                xml += self.pRedBC.xml
                xml += self.vBC.xml
                xml += self.pICMS.xml
                xml += self.vICMS.xml
                if self.vFCP.valor:
                    xml += self.vBCFCP.xml
                    xml += self.pFCP.xml
                    xml += self.vFCP.xml
                if self.vICMSDeson.valor:
                    xml += self.vICMSDeson.xml
                    xml += self.motDesICMS.xml
            elif self.CST.valor == u'30':
                xml += self.modBCST.xml
                if self.modBCST.valor == 4:
                    xml += self.pMVAST.xml
                xml += self.pRedBCST.xml
                xml += self.vBCST.xml
                xml += self.pICMSST.xml
                xml += self.vICMSST.xml
                if self.vFCPST.valor:
                    xml += self.vBCFCPST.xml
                    xml += self.pFCPST.xml
                    xml += self.vFCPST.xml
                if self.vICMSDeson.valor:
                    xml += self.vICMSDeson.xml
                    xml += self.motDesICMS.xml
            elif self.CST.valor in (u'40', u'41', u'50'):
                if self.repasse and self.CST.valor == u'41':
                    xml += self.vBCSTRet.xml
                    xml += self.vICMSSTRet.xml
                    xml += self.vBCSTDest.xml
                    xml += self.vICMSSTDest.xml
                else:
                    if self.vICMSDeson.valor:
                        xml += self.vICMSDeson.xml
                        xml += self.motDesICMS.xml
            elif self.CST.valor == u'51':
                xml += self.modBC.xml
                xml += self.pRedBC.xml
                xml += self.vBC.xml
                xml += self.pICMS.xml
                xml += self.vICMSOp.xml
                xml += self.pDif.xml
                xml += self.vICMSDif.xml
                xml += self.vICMS.xml
                if self.vFCP.valor:
                    xml += self.vBCFCP.xml
                    xml += self.pFCP.xml
                    xml += self.vFCP.xml
            elif self.CST.valor == u'60':
                xml += self.vBCSTRet.xml
                if self.repasse:
                    xml += self.vICMSSTRet.xml
                    xml += self.vBCSTDest.xml
                    xml += self.vICMSSTDest.xml
                else:
                    xml += self.pST.xml
                    xml += self.vICMSSTRet.xml
                    xml += self.vBCFCPSTRet.xml
                    xml += self.pFCPSTRet.xml
                    xml += self.vFCPSTRet.xml
            elif self.CST.valor == u'61':
                xml += self.qBCMonoRet.xml
                xml += self.adRemICMSRet.xml
                xml += self.vICMSMonoRet.xml
            elif self.CST.valor == u'70':
                xml += self.modBC.xml
                xml += self.pRedBC.xml
                xml += self.vBC.xml
                xml += self.pICMS.xml
                xml += self.vICMS.xml
                if self.vFCP.valor:
                    xml += self.vBCFCP.xml
                    xml += self.pFCP.xml
                    xml += self.vFCP.xml
                xml += self.modBCST.xml
                if self.modBCST.valor == 4:
                    xml += self.pMVAST.xml
                xml += self.pRedBCST.xml
                xml += self.vBCST.xml
                xml += self.pICMSST.xml
                xml += self.vICMSST.xml
                if self.vFCPST.valor:
                    xml += self.vBCFCPST.xml
                    xml += self.pFCPST.xml
                    xml += self.vFCPST.xml
                if self.vICMSDeson.valor:
                    xml += self.vICMSDeson.xml
                    xml += self.motDesICMS.xml
            elif self.CST.valor == u'90':
                xml += self.modBC.xml
                xml += self.vBC.xml
                if self.partilha:
                    xml += self.pRedBC.xml
                xml += self.pICMS.xml
                xml += self.vICMS.xml
                if not self.partilha and self.vFCP.valor:
                    xml += self.vBCFCP.xml
                    xml += self.pFCP.xml
                    xml += self.vFCP.xml
                if self.partilha:
                    xml += self.pBCOp.xml
                    xml += self.UFST.xml
        else:  # Simples Nacional
            xml += self.CSOSN.xml
            if self.CSOSN.valor == u'101':
                xml += self.pCredSN.xml
                xml += self.vCredICMSSN.xml
            elif self.CSOSN.valor in (u'102', u'103', u'300', u'400'):
                pass
            elif self.CSOSN.valor == u'201':
                xml += self.modBCST.xml
                if self.modBCST.valor == 4:
                    xml += self.pMVAST.xml
                xml += self.pRedBCST.xml
                xml += self.vBCST.xml
                xml += self.pICMSST.xml
                xml += self.vICMSST.xml
                if self.vFCPST.valor:
                    xml += self.vBCFCPST.xml
                    xml += self.pFCPST.xml
                    xml += self.vFCPST.xml
                xml += self.pCredSN.xml
                xml += self.vCredICMSSN.xml
            elif self.CSOSN.valor in (u'202', u'203'):
                xml += self.modBCST.xml
                if self.modBCST.valor == 4:
                    xml += self.pMVAST.xml
                xml += self.pRedBCST.xml
                xml += self.vBCST.xml
                xml += self.pICMSST.xml
                xml += self.vICMSST.xml
                if self.vFCPST.valor:
                    xml += self.vBCFCPST.xml
                    xml += self.pFCPST.xml
                    xml += self.vFCPST.xml
            elif self.CSOSN.valor == u'500':
                xml += self.vBCSTRet.xml
                xml += self.pST.xml
                xml += self.vICMSSubstituto.xml
                xml += self.vICMSSTRet.xml
                xml += self.vBCFCPSTRet.xml
                xml += self.pFCPSTRet.xml
                xml += self.vFCPSTRet.xml
            elif self.CSOSN.valor == u'900':
                xml += self.modBC.valor and self.modBC.xml or ''
                xml += self.vBC.valor and self.vBC.xml or ''
                xml += self.pRedBC.valor and self.pRedBC.xml or ''
                xml += self.pICMS.valor and self.pICMS.xml or ''
                xml += self.vICMS.valor and self.vICMS.xml or ''
                xml += self.modBCST.valor and self.modBCST.xml or ''
                if self.modBCST.valor == 4 and self.pMVAST.valor:
                    xml += self.pMVAST.xml
                xml += self.pRedBCST.valor and self.pRedBCST.xml or ''
                xml += self.vBCST.valor and self.vBCST.xml or ''
                xml += self.pICMSST.valor and self.pICMSST.xml or ''
                xml += self.vICMSST.valor and self.vICMSST.xml or ''
                if self.vFCPST.valor:
                    xml += self.vBCFCPST.valor and self.vBCFCPST.xml or ''
                    xml += self.pFCPST.valor and self.pFCPST.xml or ''
                    xml += self.vFCPST.valor and self.vFCPST.xml or ''
                xml += self.pCredSN.valor and self.pCredSN.xml or ''
                xml += self.vCredICMSSN.valor and self.vCredICMSSN.xml or ''
        xml += u'</' + self.nome_tag + u'></ICMS>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            super(ICMS, self).set_xml(arquivo)

            # Para ler corretamente o ICMS, primeiro temos que descobrir em qual grupo de situacao
            # tributaria ele esta
            self.partilha = False
            self.repasse = False
            if self._le_noh(u'//det/imposto/ICMS/ICMSST') is not None:
                self.regime_tributario = 3
                self.repasse = True
                self.CST.valor = self._le_noh(u'//det/imposto/ICMS/ICMSST/CST').text or u''

            self.orig.xml = arquivo
            self.vBCSTRet.xml = arquivo
            self.vICMSSTRet.xml = arquivo
            self.vBCSTDest.xml = arquivo
            self.vICMSSTDest.xml = arquivo
            self.vBCFCPST.xml = arquivo
            self.pFCPST.xml = arquivo
            self.vFCPST.xml = arquivo
            self.pST.xml = arquivo
            self.vBCFCPSTRet.xml = arquivo
            self.pFCPSTRet.xml = arquivo
            self.vFCPSTRet.xml = arquivo
            self.vBCFCP.xml = arquivo
            self.pFCP.xml = arquivo
            self.vFCP.xml = arquivo
            self.vICMSDeson.xml = arquivo
            self.vICMSOp.xml = arquivo
            self.pDif.xml = arquivo
            self.vICMSDif.xml = arquivo
            self.qBCMonoRet.xml = arquivo
            self.adRemICMSRet.xml = arquivo
            self.vICMSMonoRet.xml = arquivo


class Imposto(nfe_400.Imposto):
    def __init__(self):
        super(Imposto, self).__init__()
        self.ICMS = ICMS()


class AutXML(nfe_400.AutXML):
    def __init__(self):
        super(AutXML, self).__init__()


class Det(nfe_400.Det):
    def __init__(self):
        super(Det, self).__init__()
        self.imposto = Imposto()


class Pag(nfe_400.Pag):
    def __init__(self):
        super(Pag, self).__init__()


class InfNFe(nfe_400.InfNFe):
    def __init__(self):
        super(InfNFe, self).__init__()
        self.det = []
        self.pag = Pag()
        self.infRespTec = nfe_400.InfRespTec()

    @property
    def xml(self):
        xml = u'<infNFe versao="%s" Id="%s">' % (self.versao.valor, self.Id.valor)
        xml += self.ide.xml
        xml += self.emit.xml
        xml += self.avulsa.xml
        xml += self.dest.xml
        xml += self.retirada.xml
        xml += self.entrega.xml
        for aut in self.autXML:
            xml += aut.xml
        for d in self.det:
            xml += d.xml
        xml += self.total.xml
        xml += self.transp.xml
        xml += self.cobr.xml
        xml += self.pag.xml
        xml += self.infAdic.xml
        xml += self.exporta.xml
        xml += self.compra.xml
        xml += self.cana.xml
        xml += self.infRespTec.xml
        xml += u'</infNFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        super(InfNFe, self).set_xml(arquivo)
        self.versao.xml = arquivo
        self.Id.xml = arquivo
        self.ide.xml = arquivo
        self.emit.xml = arquivo
        self.avulsa.xml = arquivo
        self.dest.xml = arquivo
        self.retirada.xml = arquivo
        self.entrega.xml = arquivo
        self.autXML = self.le_grupo(u'//NFe/infNFe/autXML', AutXML)
        self.det = self.le_grupo(u'//NFe/infNFe/det', Det)
        self.total.xml = arquivo
        self.transp.xml = arquivo
        self.cobr.xml = arquivo
        self.pag.xml = arquivo
        self.infAdic.xml = arquivo
        self.exporta.xml = arquivo
        self.compra.xml = arquivo
        self.cana.xml = arquivo
        self.infRespTec.xml = arquivo


class NFCe(nfe_400.NFe):
    def __init__(self):
        super(NFCe, self).__init__()
        self.namespace = NAMESPACE_NFE
        self.infNFe = InfNFe()
        self.infNFeSupl = InfNFeSupl()

    @property
    def xml(self):
        xml = ABERTURA
        xml += u'<NFe xmlns="http://www.portalfiscal.inf.br/nfe">'
        xml += self.infNFe.xml
        xml += self.infNFeSupl.xml
        self.Signature.URI = u'#' + self.infNFe.Id.valor
        xml += self.Signature.xml
        xml += u'</NFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.infNFe.xml = arquivo
            self.infNFeSupl.xml = arquivo
            self.Signature.xml = self._le_noh(u'//NFe/sig:Signature')

    def monta_chave(self):
        self.gera_nova_chave()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
