# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
import os
from nfe.pysped.xml_sped import *
from nfe.pysped.nfe.manual_500 import consrecinfe_310
from nfe.nfe_400.manual_600.nfe_400 import NFe, ESQUEMA_ATUAL
from nfe.nfe_400.manual_600.cancnfe import RetCancNFe

DIRNAME = os.path.dirname(__file__)


class ConsReciNFe(consrecinfe_310.ConsReciNFe):
    def __init__(self):
        super(ConsReciNFe, self).__init__()
        self.versao = TagDecimal(nome=u'consReciNFe', codigo=u'BP01', propriedade=u'versao',
                                 namespace=NAMESPACE_NFE, valor=u'4.00', raiz=u'/')
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'consReciNFe_v4.00.xsd'


class InfProt(consrecinfe_310.InfProt):
    def __init__(self):
        super(InfProt, self).__init__()


class ProtNFe(consrecinfe_310.ProtNFe):
    def __init__(self):
        super(ProtNFe, self).__init__()
        self.versao = TagDecimal(nome=u'protNFe', codigo=u'PR01', propriedade=u'versao',
                                 namespace=NAMESPACE_NFE, valor=u'4.00', raiz=u'/')
        self.infProt = InfProt()


class RetConsReciNFe(consrecinfe_310.RetConsReciNFe):
    def __init__(self):
        super(RetConsReciNFe, self).__init__()
        self.versao = TagDecimal(nome=u'retConsReciNFe', codigo=u'BR01', propriedade=u'versao',
                                 namespace=NAMESPACE_NFE, valor=u'4.00', raiz=u'/')
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'retConsReciNFe_v4.00.xsd'

    @property
    def xml(self):
        return super(RetConsReciNFe, self).xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.nRec.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.cMsg.xml = arquivo
            self.xMsg.xml = arquivo
            self.protNFe = self.le_grupo(u'//retConsReciNFe/protNFe', ProtNFe)
            for pn in self.protNFe:
                self.dic_protNFe[pn.infProt.chNFe.valor] = pn


class ProcNFe(consrecinfe_310.ProcNFe):
    def __init__(self):
        super(ProcNFe, self).__init__()
        self.versao = TagDecimal(nome=u'nfeProc', codigo=u'XR01', propriedade=u'versao',
                                 namespace=NAMESPACE_NFE, valor=u'4.00', raiz=u'/')
        self.NFe = NFe()
        self.protNFe = ProtNFe()
        self.cancNfe = RetCancNFe()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'procNFe_v4.00.xsd'


    def get_xml(self):
        xml = XMLNFe.get_xml(self)
        xml += ABERTURA
        xml += self.versao.xml
        xml += self.NFe.xml.replace(ABERTURA, u'')
        if self.protNFe.infProt.Id.valor or self.protNFe.infProt.cStat.valor:
            xml += self.protNFe.xml.replace(ABERTURA, u'')
        # if self.cancNfe.xml and self.cancNfe.infCanc.cStat.valor:
        #     xml += self.cancNfe.xml.replace(ABERTURA, u'')

        xml += u'</nfeProc>'
        return xml

    def set_xml(self, arquivo):
        if self._le_xml(arquivo):
            self.NFe.xml     = arquivo
            self.protNFe.xml = arquivo
            self.cancNfe.xml = arquivo

    xml = property(get_xml, set_xml)
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
