# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""

from nfe.pysped.nfe.httplib_extras import HTTPSSignedConnection
from nfe.pysped.nfe.webservices_flags import *
from nfe.nfe_400.webservices_flag import *
from datetime import datetime
from pytz import timezone
import time

#
# Manual do Contribuinte versão 6.00
# NF-e leiaute 4.00
#
import webservices
from manual_600.soap import SOAPEnvio, SOAPRetorno
from manual_600.envinfe import EnviNFe, RetEnviNFe
from manual_600.consrecinfe import ConsReciNFe, RetConsReciNFe, ProtNFe
from manual_600.cancnfe import RetCancNFe
from manual_600.cancnfe_evento import EnvEvento, RetEnvEvento, ProcEventoNFe
from manual_600.inutnfe import InutNFe, RetInutNFe, ProcInutNFe
from manual_600.conssitnfe import ConsSitNFe, RetConsSitNFe
from manual_600.conscad import ConsCad, RetConsCad
from manual_600.consstatserv import ConsStatServ, RetConsStatServ
from manual_600.carta_correcao import EnvEvento as EnvEventoCCe
from manual_600.carta_correcao import RetEnvEvento as RetEnvEventoCCe
from manual_600.carta_correcao import ProcEventoNFe as ProcEventoNFeCCe

#
# Manifesto destinatario
#
from nfe.pysped.nfe.manifestacao_destinatario import EnvConfRecebto_200, RetEnvConfRecebto_200
from nfe.pysped.nfe.manifestacao_destinatario import ProcEventoNFeRecebto_200
from nfe.pysped.nfe.manifestacao_destinatario import NFeDistribuicaoDFe
from nfe.pysped.nfe.manifestacao_destinatario import RetDistDFeInt
from nfe.pysped.nfe.manifestacao_destinatario import SOAPEnvio_manifest, SOAPRetorno_manifest
from nfe.pysped.nfe.manifestacao_destinatario.nfedistribuicaoDFe import DistNSU, ConsChNFe
from nfe.pysped.nfe.manifestacao_destinatario.consnfedest import ConsNFeDest, RetConsNFeDest

#
# DANFE
#
from nfe.pysped.nfe.danfe.danferetrato import *
from nfe import version
import pytz
import tempfile

# Processador
from nfe.pysped.nfe.processador_nfe import ProcessadorNFe as Process

_prot = {
    '2': 'PROTOCOL_TLS',
    '3': 'PROTOCOL_TLSv1',
    '4': 'PROTOCOL_TLSv1_1',
    '5': 'PROTOCOL_TLSv1_2',
}


class ProcessoNFe(object):
    def __init__(self, webservice=0, envio=None, resposta=None):
        self.webservice = webservice
        self.envio = envio
        self.resposta = resposta


# noinspection PyTypeChecker
class ProcessadorNFe(Process):
    """
    Processador da nota fiscal eletronica
    :author: Pierre Barbosa <pierre.barbosa[at]siginformatica.com.br>
    """
    def __init__(self, certify=None, key=None, environment=2, state=u'', contingency=u'',
                 tentativas=20, timeout=10):
        super(ProcessadorNFe, self).__init__()
        self.ambiente = environment
        self.estado = state
        self.versao = u'4.00'
        self.certificado.cert_str = certify
        self.certificado.key_str = key
        self.contingencia = contingency
        self._soap_envio = SOAPEnvio()
        self._soap_retorno = SOAPRetorno()
        self.tentativas = tentativas or 20
        self.timeout = timeout or 10

    def _conectar_servico(self, servico, envio, resposta):
        self.logger.info(u'>> %s-%s v-%s' % (
            self.ambiente, u'Producao' if self.ambiente == 1 else u'Homologacao', self.versao))
        webservice = webservices.ESTADO_WS[self.versao][self.contingencia or self.estado]
        webservice = webservice[self.ambiente][servico]
        self.logger.info(self.contingencia or u'>> %s/%s' % (self.estado, UF_CODIGO[self.estado]))
        map(lambda m: self.logger.info(u'>> %s: %s' % m), webservice.items())
        self._soap_envio.webservice = webservice['webservice']
        self._soap_envio.metodo = webservice['metodo']
        self._soap_envio.cUF = UF_CODIGO[self.estado]
        self._soap_envio.namespace = webservice['namespace']
        self._soap_envio.envio = envio
        self._soap_retorno.webservice = webservice['webservice']
        self._soap_retorno.metodo = webservice['metodo']
        self._soap_retorno.resposta = resposta
        self._servidor = webservice['servidor']
        self._url = webservice['url']
        self.certificado.prepara_certificado_arquivo_pfx()

        # Verifica vencimento do certificado
        hoje = datetime.now(timezone('UTC')).astimezone(timezone('Brazil/East'))
        validade = self.certificado.data_fim_validade
        if validade.strftime('%Y%m%d') < hoje.strftime('%Y%m%d'):
            error = u'Certificado digital com data expirada: %s ' % validade.strftime('%d/%m/%Y')
            self.logger.critical(error)
            self._soap_retorno.resposta.cStat.valor = u'999'
            self._soap_retorno.resposta.xMotivo.valor = error
            self._soap_retorno.resposta.cUF.valor = self._soap_envio.cUF
            self._soap_retorno.resposta.tpAmb.valor = self.ambiente
            self._soap_retorno.resposta.reason = 'OK'

            return

        nome_arq_chave = tempfile.NamedTemporaryFile('w', dir='/dev/shm')
        nome_arq_chave.write(self.certificado.chave)
        nome_arq_chave.flush()
        nome_arq_certificado = tempfile.NamedTemporaryFile('w', dir='/dev/shm')
        nome_arq_certificado.write(self.certificado.certificado)
        nome_arq_certificado.flush()
        nome_arq_cadeia_cert = open(os.path.dirname(os.path.abspath(__file__))
                                    + '/../pysped/xml_sped/cadeia-certificadora/cadeia.pem')

        # Tentativas de conexao com tempos subsequentes maiores para evitar retorno com falha de
        # conexao.
        try:
            con = HTTPSSignedConnection(self._servidor, key_file=nome_arq_chave.name,
                                        cert_file=nome_arq_certificado.name,
                                        ca_file=nome_arq_cadeia_cert.name,
                                        timeout=self.timeout)
            request_url = u'' + os.path.join('/', self._url)
            request_body = self._soap_envio.xml.encode(u'utf-8')
            request_header = self._soap_envio.header
            try:
                con.request('POST', request_url, body=request_body, headers=request_header)
                _ssl_version = con.sock.ssl_version
            except Exception as error:
                self._soap_retorno.resposta.status = 'Erro %s' % error.args[0]
                if len(error.args) > 1:
                    self._soap_retorno.resposta.reason = error.args[1]
                else:
                    self._soap_retorno.resposta.reason = ''
            else:
                for tentativa in range(self.tentativas):
                    self.logger.info(u'<<< Tentativa [%d] >>>' % (tentativa+1))
                    try:
                        time.sleep(1)  # Tenta varias vezes de 1 segundo
                        resp = con.getresponse()
                    except Exception as error:
                        if isinstance(error.args, (list, tuple)) and len(error.args) == 1:
                            self.logger.error(u'<<< Tentativa [%d] - erro conexao (connect): %s '
                                              u'>>>' % (tentativa, error.args[0]))
                            status, reason = u'Erro', error.args[0]
                        elif isinstance(error.args, (list, tuple)) and len(error.args) > 1:
                            self.logger.error(u'<<< Tentativa [%d] - erro conexao (connect): %s '
                                              u'>>>' % (tentativa, error.args[0]))
                            status, reason = error.args[0], error.args[1]
                        else:
                            self.logger.error(u'<<< Tentativa [%d] - erro conexao (SEFAZ) '
                                              u'>>>' % tentativa)
                            status, reason = u'Erro', error
                        self._soap_retorno.resposta.status = status
                        self._soap_retorno.resposta.reason = reason
                    else:
                        self._soap_retorno.resposta.version = resp.version
                        self._soap_retorno.resposta.status = resp.status
                        self._soap_retorno.resposta.reason = unicode(resp.reason.decode('utf-8'))
                        self._soap_retorno.resposta.msg = resp.msg
                        self._soap_retorno.resposta.original = unicode(resp.read().decode('utf-8'))
                        self.logger.info(u'>> URL do serviço: %s' % os.path.join(
                            self._servidor, self._url))
                        self.logger.info(u'>> Metodo da requisição: POST  Protocolo SSL: %s' % _prot.get(str(_ssl_version)))
                        self.logger.info(u'>> URL da requisição: %s' % request_url)
                        self.logger.info(u'>> Cabecalho da requisicao: %s' % request_header)
                        self.logger.info(u'>> XML envio: %s' % request_body)

                        # Retorno da SEFAZ
                        self.logger.info(u'<< Status: %s-%s' % (self._soap_retorno.resposta.status,
                                                                self._soap_retorno.resposta.reason))
                        self.logger.info(u'<< XML resposta: %s' % self._soap_retorno.resposta.original)
                        self.logger.info(u'<< Mensagem servidor: %s' % self._soap_retorno.resposta.msg)
                        if resp.status == 200:
                            self._soap_retorno.xml = self._soap_retorno.resposta.original
                            con.close()
                            break  # Termina as tentativas se obtiver sucesso
        finally:
            # Apagamos os arquivos do certificado e o da chave privada, para evitar
            # um potencial risco de segurança; muito embora o uso da chave privada
            # para assinatura exija o uso da senha, pode haver serviços que exijam
            # apenas o uso do certificado para validar a identidade, independente
            # da existência de assinatura digital
            nome_arq_chave.close()
            nome_arq_certificado.close()

    def enviar_lote(self, lista_nfe):
        arquivos = list()
        processo, _ = self.consultar_servico()
        if not processo.resposta.cStat.valor == u'107':  # Verifica se o servico estah ativo
            return processo, _
        envio = EnviNFe()
        resposta = RetEnviNFe()
        processo = ProcessoNFe(WS_NFE_AUTORIZACAO, envio, resposta)

        # Vamos assinar e validar todas as NF-e antes da transmissao evitando rejeicao na SEFAZ por
        # incorrecao no "schema" dos arquivos
        for nfe in lista_nfe if isinstance(lista_nfe, list) else [lista_nfe]:
            self.certificado.assina_xmlnfe(nfe)
            nfe.validar()
            arquivo_nome = nfe.chave + u'-nfe-cert.xml'
            arquivo = nfe.xml.encode('utf-8')
            arquivos.append((arquivo_nome, arquivo))

        envio.NFe = lista_nfe
        envio.idLote.valor = unicode(self.ambiente) + datetime.now().strftime('%Y%m%d%H%M%S')
        envio.validar()
        arquivo_nome = unicode(envio.idLote.valor) + u'-env-lot.xml'
        arquivo = envio.xml.encode('utf-8')
        arquivos.append((arquivo_nome, arquivo))
        self.logger.info(u'*** enviar lote de notas fiscais ***')
        self._conectar_servico(WS_NFE_AUTORIZACAO, envio, resposta)
        arquivo_nome = unicode(envio.idLote.valor)
        if resposta.cStat.valor == u'103':
            arquivo_nome += u'-rec.xml'
        else:
            arquivo_nome += u'-rej.xml'
        arquivo = resposta.xml.encode('utf-8')
        arquivos.append((arquivo_nome, arquivo))

        return processo, arquivos

    def consultar_recibo(self, recibo):
        arquivos = list()
        envio = ConsReciNFe()
        resposta = RetConsReciNFe()
        processo = ProcessoNFe(WS_NFE_RET_AUTORIZACAO, envio, resposta)
        envio.tpAmb.valor = self.ambiente
        envio.nRec.valor = recibo
        envio.validar()
        novo_arquivo_nome = unicode(envio.nRec.valor) + u'-rec-ped.xml'
        novo_arquivo = envio.xml.encode('utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))
        self.logger.info(u'*** consulta de lote ***')
        self.logger.info(u'Lote %s' % recibo)
        for cont in range(1, 16):
            time.sleep(1)
            self._conectar_servico(WS_NFE_RET_AUTORIZACAO, envio, resposta)
            if resposta.cStat.valor != u'105':
                break
            self.logger.info('Numero de tentativas de consulta do lote (105): %d' % cont)
        novo_arquivo_nome = unicode(envio.nRec.valor)
        if resposta.cStat.valor == u'104':
            novo_arquivo_nome += u'-rec-proc.xml'
        else:
            novo_arquivo_nome += u'-rec-rej.xml'
        novo_arquivo = resposta.xml.encode('utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))

        # Salvar os resultados dos processamentos
        for pn in resposta.protNFe:
            novo_arquivo_nome = unicode(pn.infProt.chNFe.valor)
            if pn.infProt.cStat.valor == u'100':  # NF-e autorizada
                novo_arquivo_nome += u'-nfe-aut.xml'
            elif pn.infProt.cStat.valor in (u'110', u'301', u'302'):  # NF-e denegada
                novo_arquivo_nome += u'-nfe-den.xml'
            else:  # NF-e rejeitada
                novo_arquivo_nome += u'-nfe-rej.xml'
            novo_arquivo = pn.xml.encode('utf-8')
            arquivos.append((novo_arquivo_nome, novo_arquivo))

        return processo, arquivos

    def manifesto_destinatario(self, cnpj, tipo_evento, chave, motivo=None):
        arquivos = list()
        # Não precisa consultar, a consulta é na sefaz-mg e o manifesto é no ambiente nacional, portanto
        # não faz sentido consultar servico aqui.
        # processo, _ = self.consultar_servico()
        # if not processo.resposta.cStat.valor == u'107':  # Verifica se o servico estah ativo
        #     return processo, _
        envio = EnvConfRecebto_200()
        resposta = RetEnvConfRecebto_200()
        processo = ProcessoNFe(WS_RECEPCAO_EVENTO, envio, resposta)
        self.caminho = self.monta_caminho_nfe(chave)
        envio.infEvento.tpAmb.valor = self.ambiente
        envio.infEvento.chNFe.valor = chave
        envio.infEvento.descEvento.valor = self._get_tp_evento_manifesto(tipo_evento)
        envio.infEvento.nSeqEvento.valor = 1
        envio.infEvento.cOrgao.valor = 91  # <-- Sempre no ambiente nacional
        envio.infEvento.tpEvento.valor = tipo_evento
        envio.infEvento.CNPJ.valor = cnpj
        envio.infEvento.xJust.valor = motivo if motivo else str()
        dt = datetime.now()
        dt = dt.replace(tzinfo=pytz.utc)
        data_hora_tz = datetime.astimezone(dt, pytz.timezone("America/Sao_Paulo"))
        data_evento = datetime.strftime(data_hora_tz, u'%Y-%m-%dT%H:%M:%S') + str(data_hora_tz)[-6:]
        envio.infEvento.dhEvento.valor = data_evento
        self.certificado.prepara_certificado_arquivo_pfx()
        self.certificado.assina_xmlnfe(envio)
        envio.validar()
        novo_arquivo_nome = unicode(envio.infEvento.chNFe.valor) + u'-consulta-evento.xml'
        novo_arquivo = envio.xml.encode('utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))
        self.logger.info(u'*** manifestacao destinatario ***')
        self._conectar_servico(WS_RECEPCAO_EVENTO, envio, resposta)
        if resposta.cStat.valor == u'128':
            processo_evento_nfe = ProcEventoNFeRecebto_200()
            processo_evento_nfe.envEvento = envio
            processo_evento_nfe.retEnvEvento = resposta
            processo_evento_nfe.validar()
            processo.processo_evento_nfe = processo_evento_nfe
            novo_arquivo_nome = unicode(envio.infEvento.chNFe.valor)
            if resposta.infEvento.cStat.valor == u'135':
                novo_arquivo_nome += u'-evento-aut.xml'
            else:
                novo_arquivo_nome += u'-evento-rej.xml'

            novo_arquivo = resposta.xml.encode('utf-8')
            arquivos.append((novo_arquivo_nome, novo_arquivo))

        return processo, arquivos

    @staticmethod
    def _get_tp_evento_manifesto(evento):
        desc_evento = {'210200': 'Confirmacao da Operacao',
                       '210210': 'Ciencia da Operacao',
                       '210220': 'Desconhecimento da Operacao',
                       '210240': 'Operacao nao Realizada'}

        return desc_evento.get(evento)

    def consultar_notas_destinatario(self, cnpj, nsu=0, indicador_nfe=0, indicador_emissor=0):
        arquivos = list()
        processo, _ = self.consultar_servico()
        if not processo.resposta.cStat.valor == u'107':  # Verifica se o servico estah ativo
            return processo, _
        envio = NFeDistribuicaoDFe()
        resposta = RetDistDFeInt()
        processo = ProcessoNFe(WS_NFE_DISTRIBUICAO_DFE, envio, resposta)
        self.caminho = self.monta_caminho_nfe(cnpj)
        envio.tpAmb.valor = self.ambiente
        c_uf_autor = unicode(UF_CODIGO[self.estado])
        envio.cUFAutor.valor = c_uf_autor
        envio.CNPJ.valor = cnpj
        dnsu = DistNSU()
        dnsu.ultNSU.valor = '%015d' % int(nsu)
        envio.distNSU.append(dnsu)
        self.certificado.prepara_certificado_arquivo_pfx()
        envio.validar()
        arquivo_nome = unicode(envio.CNPJ.valor) + u'-consulta-cnpj-evento.xml'
        arquivo = envio.xml.encode(u'utf-8')
        arquivos.append((arquivo_nome, arquivo))
        self.logger.info(u'*** consulta destinatario ***')
        self._soap_envio = SOAPEnvio_manifest()
        self._soap_retorno = SOAPRetorno_manifest()
        self._conectar_servico(WS_NFE_DISTRIBUICAO_DFE, envio, resposta)
        arquivos.extend([(u'nsu_%s-%s' % (r.NSU.valor,
                          r.schema.valor), r.docZip.valor) for r in resposta.loteDistDFeInt])
        map(lambda m: self.logger.info(u'<< %s: %s' % (m[0], m[1])), arquivos)

        return processo, arquivos

    def download_xml(self, cnpj, chave):
        arquivos = list()
        processo, _ = self.consultar_servico()
        if not processo.resposta.cStat.valor == u'107':  # Verifica se o servico estah ativo
            return processo, _
        envio = NFeDistribuicaoDFe()
        resposta = RetDistDFeInt()
        processo = ProcessoNFe(WS_NFE_DISTRIBUICAO_DFE, envio, resposta)
        self.caminho = self.monta_caminho_nfe(cnpj)
        envio.tpAmb.valor = self.ambiente
        c_uf_autor = unicode(UF_CODIGO[self.estado])
        envio.cUFAutor.valor = c_uf_autor
        envio.CNPJ.valor = cnpj
        chnfe = ConsChNFe()
        chnfe.chNFe.valor = chave
        envio.consChNFe.append(chnfe)
        self.certificado.prepara_certificado_arquivo_pfx()
        envio.validar()
        novo_arquivo_nome = unicode(envio.CNPJ.valor) + u'-consulta-chnfe-evento.xml'
        novo_arquivo = envio.xml.encode(u'utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))
        self.logger.info(u'*** baixar arquivo xml ***')
        self._soap_envio = SOAPEnvio_manifest()
        self._soap_retorno = SOAPRetorno_manifest()
        self._conectar_servico(WS_NFE_DISTRIBUICAO_DFE, envio, resposta)

        return processo, arquivos

    # TODO: Dividir o metodo para pessoa fisica (CPF) e pessoa juridica (CNPJ)
    def consultar_cadastro_contribuinte(self, cpf_cnpj, inscricao_estadual=None):
        arquivos = list()
        envio = ConsCad()
        resposta = RetConsCad()
        processo = ProcessoNFe(WS_CAD_CONSULTA_CADASTRO, envio, resposta)
        envio.infCons.UF.valor = self.estado
        if inscricao_estadual:
            envio.infCons.IE.valor = inscricao_estadual
            nome = 'IE_' + inscricao_estadual
        elif len(cpf_cnpj) == 11:
            envio.infCons.CPF.valor = cpf_cnpj
            nome = 'CPF_' + cpf_cnpj
        else:
            envio.infCons.CNPJ.valor = cpf_cnpj
            nome = 'CNPJ_' + cpf_cnpj
        envio.validar()
        self.logger.info(u'*** consulta cadastro ***')
        self._conectar_servico(WS_CAD_CONSULTA_CADASTRO, envio, resposta)
        novo_arquivo_nome = nome + u'-cons-cad.xml'
        novo_arquivo = resposta.xml.encode('utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))

        return processo, arquivos

    # FIX: A carta de correcao pode ser tratada em lotes contendo no maximo 20 eventos
    def carta_correcao(self, chave, cnpj, correcao, sequencia=1):
        arquivos = list()
        processo, _ = self.consultar_servico()
        if not processo.resposta.cStat.valor == u'107':  # Verifica se o servico estah ativo
            return processo, _
        envio = EnvEventoCCe()
        resposta = RetEnvEventoCCe()
        processo = ProcessoNFe(WS_RECEPCAO_EVENTO_CCE, envio, resposta)
        self.caminho = self.monta_caminho_nfe(chave)
        envio.idLote.valor = unicode(self.ambiente) + datetime.now().strftime('%Y%m%d%H%M%S')
        envio.infEvento.tpAmb.valor = self.ambiente
        envio.infEvento.cOrgao.valor = self.contingencia and 90 or UF_CODIGO[self.estado]
        envio.infEvento.CNPJ.valor = cnpj
        envio.infEvento.chNFe.valor = chave
        dt = datetime.now()
        dt = dt.replace(tzinfo=pytz.utc)
        data_hora_tz = datetime.astimezone(dt, pytz.timezone("Brazil/East"))
        data_evento = datetime.strftime(data_hora_tz, u'%Y-%m-%dT%H:%M:%S') + str(data_hora_tz)[-6:]
        envio.infEvento.dhEvento.valor = data_evento
        envio.infEvento.detEvento.xCorrecao.valor = correcao
        envio.infEvento.nSeqEvento.valor = sequencia
        self.certificado.prepara_certificado_arquivo_pfx()
        self.certificado.assina_xmlnfe(envio)
        envio.validar()
        novo_arquivo_nome = unicode(
            envio.infEvento.chNFe.valor).strip().rjust(44, u'0') + u'-ped-cce.xml'
        novo_arquivo = envio.xml.encode('utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))
        self._conectar_servico(WS_RECEPCAO_EVENTO_CCE, envio, resposta)
        if resposta.cStat.valor == u'128':  # Lote processado
            processo_correcao_nfe = ProcEventoNFeCCe()
            processo_correcao_nfe.envEvento = envio
            processo_correcao_nfe.retEnvEvento = resposta
            processo.processo_correcao_nfe = processo_correcao_nfe
            novo_arquivo_nome = unicode(envio.infEvento.chNFe.valor)
            if resposta.infEvento.cStat.valor == u'135':
                novo_arquivo_nome += u'-cce-aut.xml'  # Correcao autorizada
            else:
                novo_arquivo_nome += u'-cce-rej.xml'
            novo_arquivo = resposta.xml.encode('utf-8')
            arquivos.append((novo_arquivo_nome, novo_arquivo))

        return processo, arquivos

    def cancelar_nota(self, chave, numero_protocolo=None, justificativa=None):
        arquivos = list()
        processo, _ = self.consultar_servico()
        if not processo.resposta.cStat.valor == u'107':  # Verifica se o servico estah ativo
            return processo, _
        envio = EnvEvento()
        resposta = RetEnvEvento()
        processo = ProcessoNFe(WS_RECEPCAO_EVENTO_CANCELAMENTO, envio, resposta)
        self.caminho = self.monta_caminho_nfe(chave)
        envio.infEvento.tpAmb.valor = self.ambiente
        envio.infEvento.chNFe.valor = chave
        envio.infEvento.nProt.valor = numero_protocolo
        envio.infEvento.xJust.valor = justificativa
        envio.infEvento.cOrgao.valor = UF_CODIGO[self.estado]
        dt = datetime.now()
        dt = dt.replace(tzinfo=pytz.utc)
        data_hora_tz = datetime.astimezone(dt, pytz.timezone("Brazil/East"))
        data_evento = datetime.strftime(data_hora_tz, u'%Y-%m-%dT%H:%M:%S') + str(data_hora_tz)[-6:]
        envio.infEvento.dhEvento.valor = data_evento
        envio.infEvento.CNPJ.valor = chave[6:20]
        self.certificado.prepara_certificado_arquivo_pfx()
        self.certificado.assina_xmlnfe(envio)
        envio.validar()
        novo_arquivo_nome = unicode(envio.infEvento.chNFe.valor) + u'-ped-can.xml'
        novo_arquivo = envio.xml.encode('utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))
        self.logger.info(u'*** cancelamento de nota fiscal ***')
        self._conectar_servico(WS_RECEPCAO_EVENTO_CANCELAMENTO, envio, resposta)
        if resposta.cStat.valor == u'128':
            processo_cancelamento_nfe = ProcEventoNFe()
            processo_cancelamento_nfe.envEvento = envio
            processo_cancelamento_nfe.retEnvEvento = resposta
            processo_cancelamento_nfe.validar()
            processo.processo_cancelamento_nfe = processo_cancelamento_nfe
            if resposta.retEvento.infEvento.cStat.valor == u'135':
                novo_arquivo_nome = unicode(envio.infEvento.chNFe.valor) + u'-can.xml'
            else:
                novo_arquivo_nome += u'-can-rej.xml'
            novo_arquivo = resposta.xml.encode('utf-8')
            arquivos.append((novo_arquivo_nome, novo_arquivo))

        return processo, arquivos

    def inutilizar_nota(self, ano, cnpj, serie, inicio=1, fim=1, justificativa=None):
        arquivos = list()
        envio = InutNFe()
        resposta = RetInutNFe()
        processo = ProcessoNFe(WS_NFE_INUTILIZACAO, envio, resposta)
        envio.infInut.tpAmb.valor = self.ambiente
        envio.infInut.cUF.valor = UF_CODIGO[self.estado]
        envio.infInut.ano.valor = ano or datetime.now().strftime(u'%y')
        envio.infInut.CNPJ.valor = cnpj
        envio.infInut.serie.valor = serie
        envio.infInut.nNFIni.valor = inicio
        envio.infInut.nNFFin.valor = fim
        envio.infInut.xJust.valor = justificativa
        envio.gera_nova_chave()
        self.certificado.prepara_certificado_arquivo_pfx()
        self.certificado.assina_xmlnfe(envio)
        envio.validar()
        novo_arquivo_nome = unicode(envio.chave) + u'-ped-inu.xml'
        novo_arquivo = envio.xml.encode('utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))
        self.logger.info(u'*** inutilizar nota fiscal ***')
        self.logger.info(u'>> Faixa: %03d a %03d - Serie %s' % (int(inicio), int(fim), int(serie)))
        self.logger.info(u'>> ID%s (chave)' % envio.chave)
        self._conectar_servico(WS_NFE_INUTILIZACAO, envio, resposta)
        processo_inutilizacao_nfe = ProcInutNFe()

        # Se for autorizada, monta o processo de inutilização
        if resposta.infInut.cStat.valor == u'102':
            processo_inutilizacao_nfe.inutNFe = envio
            processo_inutilizacao_nfe.retInutNFe = resposta
            processo_inutilizacao_nfe.validar()
            processo.processo_inutilizacao_nfe = processo_inutilizacao_nfe
        if self.salvar_arquivos:
            novo_arquivo_nome = unicode(envio.chave)

            # Inutilização autorizada
            if resposta.infInut.cStat.valor == u'102':
                novo_arquivo_nome += u'-inu-aut.xml'
            else:
                novo_arquivo_nome += u'-inu-rej.xml'

            novo_arquivo = resposta.xml.encode(u'utf-8')
            arquivos.append((novo_arquivo_nome, novo_arquivo))

            # Se for autorizada, monta o processo de inutilização
            if resposta.infInut.cStat.valor == u'102':
                novo_arquivo_nome = unicode(envio.chave) + u'-inu-nfe.xml'
                novo_arquivo = processo_inutilizacao_nfe.xml.encode(u'utf-8')
                arquivos.append((novo_arquivo_nome, novo_arquivo))

                # Estranhamente, o nome desse arquivo, pelo manual, deve ser chave-inu.xml
                novo_arquivo_nome = unicode(envio.chave) + u'-inu.xml'
                novo_arquivo = processo_inutilizacao_nfe.xml.encode(u'utf-8')
                arquivos.append((novo_arquivo_nome, novo_arquivo))

        return processo, arquivos

    def consultar_nota(self, chave):
        arquivos = list()
        processo, _ = self.consultar_servico()
        if not processo.resposta.cStat.valor == u'107':  # Verifica se o servico estah ativo
            return processo, _
        envio = ConsSitNFe()
        resposta = RetConsSitNFe()
        processo = ProcessoNFe(WS_NFE_CONSULTA_PROTOCOLO, envio, resposta)
        self.caminho = self.monta_caminho_nfe(chave)
        envio.tpAmb.valor = self.ambiente
        envio.chNFe.valor = chave
        envio.validar()
        novo_arquivo_nome = unicode(chave) + u'-ped-sit.xml'
        novo_arquivo = envio.xml.encode(u'utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))
        self.logger.info(u'*** consultar nota fiscal ***')
        self._conectar_servico(WS_NFE_CONSULTA_PROTOCOLO, envio, resposta)
        novo_arquivo_nome = unicode(chave) + u'-sit.xml'
        novo_arquivo = resposta.xml.encode(u'utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))

        return processo, arquivos

    def consultar_servico(self):
        arquivos = list()
        envio = ConsStatServ()
        resposta = RetConsStatServ()
        processo = ProcessoNFe(WS_NFE_STATUS_SERVICO, envio, resposta)
        envio.tpAmb.valor = self.ambiente
        envio.cUF.valor = UF_CODIGO[self.estado]
        envio.data = datetime.now()
        envio.validar()
        arquivo_nome = envio.data.strftime(u'%Y%m%dT%H%M%S') + u'-ped-sta.xml'
        arquivo = envio.xml.encode('utf-8')
        arquivos.append((arquivo_nome, arquivo))
        self.logger.info(u'*** consultar servico ***')
        self._conectar_servico(WS_NFE_STATUS_SERVICO, envio, resposta)
        arquivo_nome = envio.data.strftime(u'%Y%m%dT%H%M%S') + u'-sta.xml'
        arquivo = resposta.xml.encode('utf-8')
        arquivos.append((arquivo_nome, arquivo))

        return processo, arquivos

    def processar_notas(self, lista_nfe):
        arquivos = list()
        self.logger.info(u'*** montagem do lote de notas fiscais ***')
        for nfe in lista_nfe if isinstance(lista_nfe, list) else [lista_nfe]:
            nfe.monta_chave()
            self.logger.info(u'%s=> %s' % (lista_nfe.index(nfe) + 1, nfe.infNFe.Id.valor))
        processo, novos_arquivos = self.enviar_lote(lista_nfe)
        
        # a partir da versao '4.47.5', quebra o envio em duas partes para nao perder o lote
        if self.__dict__.get('nova_versao'):
            return processo, novos_arquivos
        
        if processo.resposta.cStat.valor == u'103':
            arquivos.extend(novos_arquivos)
            processo, novos_arquivos = self.consultar_recibo(
                processo.resposta.infRec.nRec.valor)
            arquivos.extend(novos_arquivos)

        return processo, arquivos


class DANFE(object):
    def __init__(self):
        self.imprime_canhoto = True
        self.imprime_local_retirada = True
        self.imprime_local_entrega = True
        self.imprime_fatura = True
        self.imprime_duplicatas = True
        self.imprime_issqn = True
        self.caminho = u'/tmp'
        self.salvar_arquivo = False
        self.NFe = None
        self.protNFe = None
        self.retCancNFe = None
        self.danfe = None
        self.versao = u'4.00'
        self.obs_impressao = u'DANFE gerado em %(now:%d/%m/%Y as %H:%M:%S)s'
        self.nome_sistema = u''
        self.site = u''
        self.logo = u''
        self.leiaute_logo_vertical = False
        self.dados_emitente = list()

    def gerar_danfe(self):
        if self.NFe is None:
            raise ValueError(u'Não é possível gerar um DANFE sem a informação de uma NF-e')
        if self.protNFe is None:
            self.protNFe = ProtNFe()
        if self.retCancNFe is None:
            self.retCancNFe = RetCancNFe()

        # Prepara o queryset para impressão
        self.NFe.monta_chave()
        self.NFe.monta_dados_contingencia_fsda()
        self.NFe.site = self.site

        if len(self.NFe.infNFe.transp.vol) > 1:
            volume = [self.NFe.infNFe.transp.vol[0]]
            for v in self.NFe.infNFe.transp.vol[1:]:
                volume[0].qVol.valor += v.qVol.valor
                volume[0].pesoB.valor += v.pesoB.valor
                volume[0].pesoL.valor += v.pesoL.valor
            self.NFe.infNFe.transp.vol = volume

        for detalhe in self.NFe.infNFe.det:
            detalhe.NFe = self.NFe
            detalhe.protNFe = self.protNFe
            detalhe.retCancNFe = self.retCancNFe

        # Identifica se empresa e Simples Nacional. Se sim, o titulo do cabecario do produto deve
        # ser CSOSN e nao CST.
        simples_nacional = self.NFe.infNFe.emit.CRT.valor == 1

        # Prepara as bandas de impressão para cada formato
        if self.NFe.infNFe.ide.tpImp.valor == 2:
            # raise ValueError(u'DANFE em formato paisagem ainda não implementado')
            # Como o formato paisagem ainda nao foi implementado, o DANFE sera gerado no formato
            # retrato
            self.NFe.infNFe.ide.tpImp.valor = 1
            self.danfe = DANFERetrato(versao=self.versao, simples_nacional=simples_nacional)
            self.danfe.queryset = self.NFe.infNFe.det
        else:
            self.danfe = DANFERetrato(versao=self.versao, simples_nacional=simples_nacional)
            self.danfe.queryset = self.NFe.infNFe.det

        if self.imprime_canhoto:
            self.danfe.band_page_header = self.danfe.canhoto
            self.danfe.band_page_header.child_bands = []
            self.danfe.band_page_header.child_bands.append(self.danfe.remetente)
        else:
            self.danfe.band_page_header = self.danfe.remetente
            self.danfe.band_page_header.child_bands = []

        # Emissão para simples conferência / sem protocolo de autorização
        if not self.protNFe.infProt.nProt.valor:
            self.danfe.remetente.campo_variavel_conferencia()
        elif self.protNFe.infProt.cStat.valor == u'110':  # NF-e denegada
            self.danfe.remetente.campo_variavel_denegacao()
            self.danfe.remetente.obs_denegacao()
        elif self.NFe.infNFe.ide.tpEmis.valor in (2, 5,):  # Emissão em contingência com FS ou FSDA
            self.danfe.remetente.campo_variavel_contingencia_fsda()
            self.danfe.remetente.obs_contingencia_normal_scan()
        elif self.NFe.infNFe.ide.tpEmis.valor == 4:  # Emissão em contingência com DPEC
            self.danfe.remetente.campo_variavel_contingencia_dpec()
            self.danfe.remetente.obs_contingencia_dpec()
        else:  # Emissão normal ou contingência SCAN, SVC-AN e SVC-RS
            self.danfe.remetente.campo_variavel_normal()
            # Contingência SCAN,SVC-AN e SVC-RS
            if self.NFe.infNFe.ide.tpEmis.valor in (3, 6, 7):
                self.danfe.remetente.obs_contingencia_normal_scan()

        # A NF-e foi cancelada, no DANFE imprimir o "carimbo" de cancelamento
        if self.retCancNFe.infCanc.tpEvento.valor:
            self.danfe.remetente.obs_cancelamento()

        # Observação de ausência de valor fiscal
        # se não houver protocolo ou se o ambiente for de homologação
        if (not self.protNFe.infProt.nProt.valor) or self.NFe.infNFe.ide.tpAmb.valor == 2:
            self.danfe.remetente.obs_sem_valor_fiscal()

        self.danfe.band_page_header.child_bands.append(self.danfe.destinatario)
        if self.imprime_local_retirada and len(self.NFe.infNFe.retirada.xml):
            self.danfe.band_page_header.child_bands.append(self.danfe.local_retirada)
        if self.imprime_local_entrega and len(self.NFe.infNFe.entrega.xml):
            self.danfe.band_page_header.child_bands.append(self.danfe.local_entrega)
        if self.imprime_fatura:
            # Pagamento a prazo
            if len(self.NFe.infNFe.cobr.dup) > 1 or len(self.NFe.infNFe.cobr.dup) == 1:
                avista = True
                for dup in self.NFe.infNFe.cobr.dup:
                    if (dup.dVenc.valor.date() > self.NFe.infNFe.ide.dhEmi.valor.date()):
                        avista = False
                        break

                if avista:
                    self.danfe.band_page_header.child_bands.append(self.danfe.fatura_a_vista)
                else:
                    if self.imprime_duplicatas:
                        self.danfe.fatura_a_prazo.elements.append(self.danfe.duplicatas)

                    self.danfe.band_page_header.child_bands.append(self.danfe.fatura_a_prazo)

            # na 4.00 nao tem como saber se eh a vista ou a prazo, pois foi retirada esta informacao
            # do xml
            # Outros pagamentos (considerado a prazo)
            # elif filter(lambda f: f.tPag.valor == u'99', self.NFe.infNFe.pag.detPag):
            #     self.danfe.band_page_header.child_bands.append(self.danfe.fatura_a_prazo)
            # else:  # Pagamentos a vista
            #     self.danfe.band_page_header.child_bands.append(self.danfe.fatura_a_vista)

        self.danfe.band_page_header.child_bands.append(self.danfe.calculo_imposto)
        self.danfe.band_page_header.child_bands.append(self.danfe.transporte)
        self.danfe.band_page_header.child_bands.append(self.danfe.cab_produto)
        if self.imprime_issqn and len(self.NFe.infNFe.total.ISSQNTot.xml):
            self.danfe.band_page_footer = self.danfe.iss
        else:
            self.danfe.band_page_footer = self.danfe.dados_adicionais
        self.danfe.band_detail = self.danfe.det_produto

        # Observação de impressão
        if self.nome_sistema:
            self.danfe.ObsImpressao.expression = self.nome_sistema + u' - ' + self.obs_impressao
        else:
            self.danfe.ObsImpressao.expression = self.obs_impressao

        # Quadro do emitente
        if self.dados_emitente:
            self.danfe.remetente.monta_quadro_emitente(self.dados_emitente)
        else:  # Sem logotipo
            if not self.logo:
                self.danfe.remetente.monta_quadro_emitente(
                    self.danfe.remetente.dados_emitente_sem_logo())
            elif self.leiaute_logo_vertical:  # Logotipo na vertical
                self.danfe.remetente.monta_quadro_emitente(
                    self.danfe.remetente.dados_emitente_logo_vertical(self.logo))
            else:  # Logotipo na horizontal
                self.danfe.remetente.monta_quadro_emitente(
                    self.danfe.remetente.dados_emitente_logo_horizontal(self.logo))

        if self.salvar_arquivo:
            nome_arq = self.caminho + self.NFe.chave + u'.pdf'
            type(self.danfe.generate_by(PDFGenerator, filename=nome_arq))

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
