#!/usr/bin/python
# -*- encoding: utf-8 -*-
__author__ = 'thiago.rodrigues'

from nfe.pysped.xml_sped import *
from nfe.pysped.nfe.manifestacao_destinatario import ESQUEMA_ATUAL
import os
import gzip
import consnfedest
import xml.etree.ElementTree as Et
DIRNAME = os.path.dirname(__file__)


class NFeDistribuicaoDFe(XMLNFe):
    def __init__(self):
        super(NFeDistribuicaoDFe, self).__init__()
        self.versao = TagDecimal(nome=u'distDFeInt', codigo=u'A01', propriedade=u'versao',
                                 namespace=NAMESPACE_NFE, valor=u'1.01', raiz=u'/')
        self.tpAmb = TagInteiro(nome=u'tpAmb', codigo=u'A03', tamanho=[1, 1, 1],
                                raiz=u'//distDFeInt')
        self.cUFAutor = TagCaracter(nome=u'cUFAutor', codigo=u'A04', tamanho=[0, 2],
                                    raiz=u'//distDFeInt')
        self.CNPJ = TagCaracter(nome=u'CNPJ', codigo=u'A05', tamanho=[0, 14],
                                raiz=u'//distDFeInt')
        self.distNSU = []
        self.consNSU = []
        self.consChNFe = []
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'distDFeInt_v1.01.xsd'

    def get_xml(self):
        xml = XMLNFe.get_xml(self)
        xml += ABERTURA
        xml += self.versao.xml
        xml += self.tpAmb.xml
        xml += self.cUFAutor.xml
        xml += self.CNPJ.xml
        for dist in self.distNSU:
            xml += dist.xml
        for cons in self.consNSU:
            xml += cons.xml
        for chnf in self.consChNFe:
            xml += chnf.xml
        xml += u'</distDFeInt>'
        return xml

    def set_xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.cUFAutor.xml = arquivo
            self.CNPJ.xml = arquivo
            self.distNSU = self.le_grupo('//distDFeInt/distNSU', DistNSU)
            self.consNSU = self.le_grupo('//distDFeInt/consNSU', ConsNSU)
            self.consChNFe = self.le_grupo('//distDFeInt/consNFe', ConsChNFe)
    xml = property(get_xml, set_xml)


class DistNSU(XMLNFe):
    def __init__(self):
        super(DistNSU, self).__init__()
        self.ultNSU = TagCaracter(nome=u'ultNSU', codigo=u'A08', tamanho=[0, 15], raiz=u'//distNSU')

    def get_xml(self):
        if not self.ultNSU.valor:
            return u''
        xml = XMLNFe.get_xml(self)
        xml += u'<distNSU>'
        xml += self.ultNSU.xml
        xml += u'</distNSU>'
        return xml

    def set_xml(self, arquivo):
        if self._le_xml(arquivo):
            self.ultNSU.xml = arquivo

    xml = property(get_xml, set_xml)


class ConsNSU(XMLNFe):
    def __init__(self):
        super(ConsNSU, self).__init__()
        self.NSU = TagCaracter(nome=u'NSU', codigo=u'A10', tamanho=[1, 15], raiz=u'//consNSU')

    def get_xml(self):
        if not self.NSU.valor:
            return u''
        xml = XMLNFe.get_xml(self)
        xml += u'<consNSU>'
        xml += self.NSU.xml
        xml += u'</consNSU>'
        return xml

    def set_xml(self, arquivo):
        if self._le_xml(arquivo):
            self.NSU.xml = arquivo

    xml = property(get_xml, set_xml)


class ConsChNFe(XMLNFe):
    def __init__(self):
        super(ConsChNFe, self).__init__()
        self.chNFe = TagCaracter(nome=u'chNFe', codigo=u'A12', tamanho=[44, 44],
                                 raiz=u'//consChNFe')

    @property
    def xml(self):
        if not self.chNFe.valor:
            return u''
        xml = XMLNFe.get_xml(self)
        xml += u'<consChNFe>'
        xml += self.chNFe.xml
        xml += u'</consChNFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.chNFe.xml = arquivo


class RetDistDFeInt(XMLNFe):
    def __init__(self):
        super(RetDistDFeInt, self).__init__()
        self.raiz = u'//retDistDFeInt'
        self.versao = TagDecimal(nome=u'retDistDFeInt', propriedade=u'versao', codigo=u'B01',
                                 namespace=NAMESPACE_NFE, valor=u'1.00', raiz=self.raiz)
        self.tpAmb = TagInteiro(nome=u'tpAmb', codigo=u'B03', tamanho=[1, 1, 1],
                                raiz=self.raiz)
        self.verAplic = TagCaracter(nome=u'verAplic', codigo=u'B04', tamanho=[1, 20],
                                    raiz=self.raiz)
        self.cStat = TagCaracter(nome=u'cStat', codigo=u'B05', tamanho=[3, 3, 3], raiz=self.raiz)
        self.xMotivo = TagCaracter(nome=u'xMotivo', codigo=u'B06', tamanho=[1, 255], raiz=self.raiz)
        self.dhResp = TagCaracter(nome=u'dhResp', codigo=u'B07', tamanho=[0, 30], raiz=self.raiz)
        self.ultNSU = TagCaracter(nome=u'ultNSU', codigo=u'B08', tamanho=[1, 15], raiz=self.raiz)
        self.maxNSU = TagCaracter(nome=u'maxNSU', codigo=u'B09', tamanho=[1, 15], raiz=self.raiz)
        self.loteDistDFeInt = []
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'retDistDFeInt_v1.00.xsd'

    def get_xml(self):
        xml = XMLNFe.get_xml(self)
        xml += ABERTURA
        xml += self.versao.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.dhResp.xml
        xml += self.ultNSU.xml
        xml += self.maxNSU.xml
        xml += u'<loteDistDFeInt>'
        for lote in self.loteDistDFeInt:
            xml += lote.xml
        xml += u'</loteDistDFeInt>'
        xml += u'</%s>' % self.raiz.replace('//', '')
        return xml

    def set_xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.dhResp.xml = arquivo
            self.ultNSU.xml = arquivo
            self.maxNSU.xml = arquivo
            self.loteDistDFeInt = self.le_grupo('//loteDistDFeInt/docZip', LoteDistDFeInt)

    xml = property(get_xml, set_xml)


class LoteDistDFeInt(XMLNFe):
    def __init__(self):
        super(LoteDistDFeInt, self).__init__()
        self.raiz = u'/'
        self.docZip = TagCaracter(nome=u'docZip', codigo=u'B11', tamaho=[1, 50], raiz=self.raiz)
        self.NSU = TagCaracter(nome=u'docZip', codigo=u'B12', propriedade=u'NSU', tamanho=[1, 15],
                               raiz=self.raiz, namespace=NAMESPACE_NFE)
        self.schema = TagCaracter(nome=u'docZip', codigo=u'B13', propriedade=u'schema',
                                  raiz=self.raiz, namespace=NAMESPACE_NFE)
        self.resNFe = []

    def get_xml(self):
        xml = XMLNFe.get_xml(self)
        xml += u'<docZip NSU="' + unicode(self.NSU.valor) + u'" schema="' + \
               unicode(self.schema.valor) + u'">'
        xml += unicode(self.docZip.valor)
        xml += u'</docZip>'
        return xml

    def set_xml(self, arquivo):
        if self._le_xml(arquivo):
            self.docZip.xml = arquivo
            self.NSU.xml = arquivo
            self.schema.xml = arquivo

    xml = property(get_xml, set_xml)


class ResNFe(consnfedest.ResNFe):
    def __init__(self):
        super(ResNFe, self).__init__()
        self.dhEmi = TagCaracter(nome=u'dhEmi', codigo=u'C08', raiz=u'//ret/resNFe',
                                 obrigatorio=False)
        self.nProt = TagCaracter(nome=u'nProt', codigo=u'C12', tamanho=[1, 15],
                                 raiz=u'//ret/resNFe')
        self.dhRecbto = TagCaracter(nome=u'dhRecbto', codigo=u'IR22', raiz=u'//ret/resNFe',
                                    obrigatorio=False)

    def get_res_nfe(self):
        pass

    def set_res_nfe(self, arquivo):
        self.chNFe.valor = self.get_valor(arquivo, u'chNFe')
        self.CNPJ.valor = self.get_valor(arquivo, u'CNPJ')
        self.CPF.valor = self.get_valor(arquivo, u'CPF')
        self.xNome.valor = self.get_valor(arquivo, u'xNome')
        self.IE.valor = self.get_valor(arquivo, u'IE')
        self.dhEmi.valor = self.get_valor(arquivo, u'dhEmi')
        self.tpNF.valor = self.get_valor(arquivo, u'tpNF')
        self.vNF.valor = self.get_valor(arquivo, u'vNF')
        self.digVal.valor = self.get_valor(arquivo, u'digVal')
        self.dhRecbto.valor = self.get_valor(arquivo, u'dhRecbto')
        self.nProt.valor = self.get_valor(arquivo, u'nProt')
        self.cSitNFe.valor = self.get_valor(arquivo, u'cSitNFe')

    def decodifica_nfe(self, diretorio, binario):
        import os
        nfe = binario.decode('base64')
        tmp_file = os.tempnam(diretorio, binario)
        arquivo = open(tmp_file, 'wb')
        arquivo.write(nfe)
        arquivo.close()
        nfe = gzip.open(tmp_file, 'rb')
        nfe_xml = nfe.read()
        nfe.close()
        nfe_xml = Et.fromstring(nfe_xml)
        self.set_res_nfe(nfe_xml)
        os.remove(tmp_file)

    @staticmethod
    def get_valor(arquivo, tag):
        namespace = '{'+NAMESPACE_NFE+'}'+tag
        try:
            return arquivo.find(namespace).text
        except AttributeError:
            return ''
