# -*- coding: utf-8 -*-

import os

from nfe.pysped.nfe.manual_401 import cancnfe_200
from nfe.pysped.xml_sped import *
from nfe.pysped.nfe.manual_500 import ESQUEMA_ATUAL


DIRNAME = os.path.dirname(__file__)


class InfCancEnviado(cancnfe_200.InfCancEnviado):
    def __init__(self):
        super(InfCancEnviado, self).__init__()


class CancNFe(cancnfe_200.CancNFe):
    def __init__(self):
        super(CancNFe, self).__init__()
        self.versao = TagDecimal(nome=u'retEvento', codigo=u'CP01', propriedade=u'versao',
                                 valor=u'1.00', raiz=u'/')
        self.infCanc = InfCancEnviado()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'cancNFe_v3.10.xsd'


class InfCancRecebido(cancnfe_200.InfCancRecebido):
    def __init__(self):
        super(InfCancRecebido, self).__init__()
        self.Id = TagCaracter(nome=u'infEvento', codigo=u'CR03', tamanho=[17, 17],
                              raiz=u'//retEvento', propriedade=u'Id', obrigatorio=False)
        self.tpAmb = TagInteiro(nome=u'tpAmb'    , codigo=u'CR05', tamanho=[1, 1],
                                raiz=u'//retEvento/infEvento', valor=2)
        self.verAplic = TagCaracter(nome=u'verAplic', codigo=u'CR06', tamanho=[1, 20],
                                    raiz=u'//retEvento/infEvento')
        self.cOrgao = TagInteiro(nome=u'cOrgao', codigo=u'CR12', tamanho=[2, 2],
                                 raiz=u'//retEvento/infEvento', obrigatorio=False)
        self.cStat = TagCaracter(nome=u'cStat', codigo=u'CR07', tamanho=[3, 3],
                                 raiz=u'//retEvento/infEvento')
        self.xMotivo = TagCaracter(nome=u'xMotivo', codigo=u'CR08', tamanho=[1, 255],
                                   raiz=u'//retEvento/infEvento')
        self.chNFe = TagCaracter(nome=u'chNFe', codigo=u'CR09', tamanho=[44, 44],
                                 raiz=u'//retEvento/infEvento', obrigatorio=False)
        self.tpEvento = TagInteiro(nome=u'tpEvento', codigo=u'CR13', tamanho=[6, 6],
                                   raiz=u'//retEvento/infEvento', obrigatorio=False)
        self.xEvento = TagCaracter(nome=u'xEvento', codigo=u'CR14', tamanho=[5, 60],
                                   raiz=u'//retEvento/infEvento', obrigatorio=False)
        self.CNPJDest = TagCaracter(nome=u'CNPJDest', codigo=u'CR15', tamanho=[11, 14],
                                    raiz=u'//retEvento/infEvento', obrigatorio=False)
        self.dhRegEvento = TagDataHoraUTC(nome=u'dhRegEvento', codigo=u'CR10',
                                          raiz=u'//retEvento/infEvento', obrigatorio=False)

    @property
    def xml(self):
        xml = XMLNFe.get_xml(self)

        if self.Id.xml:
            xml += self.Id.xml
        else:
            xml += u'<infEvento>'

        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cOrgao.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.chNFe.xml
        xml += self.tpEvento.xml
        xml += self.xEvento.xml
        xml += self.CNPJDest.xml
        xml += self.dhRegEvento.xml
        xml += u'</infEvento>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.Id.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cOrgao.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.chNFe.xml = arquivo
            self.tpEvento.xml = arquivo
            self.xEvento.xml = arquivo
            self.CNPJDest.xml = arquivo
            self.dhRegEvento.xml = arquivo


class RetCancNFe(cancnfe_200.RetCancNFe):
    def __init__(self):
        super(RetCancNFe, self).__init__()
        self.versao = TagDecimal(nome=u'retCancNFe', codigo=u'CR01', propriedade=u'versao',
                                 valor=u'3.10', raiz=u'/')
        self.infCanc = InfCancRecebido()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'retCancNFe_v3.10.xsd'

    def protocolo_cancelamento(self):
        if not self.infCanc.tpEvento.valor:
            return u''

        result = u'%s - %s' % (self.infCanc.Id.valor[2:], self.infCanc.dhRegEvento.formato_danfe())

        return result


class ProcCancNFe(cancnfe_200.ProcCancNFe):
    def __init__(self):
        super(ProcCancNFe, self).__init__()
        #
        # Atenção --- a tag procCancNFe tem que começar com letra minúscula, para
        # poder validar no XSD.
        #
        self.versao = TagDecimal(nome=u'procCancNFe', propriedade=u'versao', namespace=NAMESPACE_NFE, valor=u'3.10', raiz=u'/')
        self.cancNFe = CancNFe()
        self.retCancNFe = RetCancNFe()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'procCancNFe_v3.10.xsd'
