# -*- coding: utf-8 -*-
# #############################################################################
#
# Copyright (c) 2009 All Rights Reserved. Luiz Fernando Maciel Franca
# www.siginformatica.com.br luiz@siginformatica.com.br
#
##############################################################################


from nfe.pysped.nfe.httplib_extras import HTTPSSignedConnection
from datetime import datetime
import time
import logging
import os
from pytz import timezone
from nfe.pysped.nfe.nfse.nfse_202 import EnviarLoteRpsSincronoEnvio, EnviarLoteRpsSincronoResposta

try:
    from collections import OrderedDict
except ImportError:
    from ordereddict import OrderedDict

from webservices_flags import *
from nfe.pysped.nfe.nfse.certificado import Certificado

#
# Manual do Contribuinte versão 5.00
# NF-e leiaute 2.02
#
import webservices as ws_nfse
from soap_202 import SOAPEnvio, SOAPRetorno
# from manual_500 import SOAPEnvio_310, SOAPRetorno_310
# from manual_500 import EnviNFe_310, RetEnviNFe_310
# from manual_500 import ConsReciNFe_310, RetConsReciNFe_310, ProtNFe_310, ProcNFe_310
# from manual_500 import RetCancNFe_310, EnvEvento_310, RetEnvEvento_310, ProcEventoNFe_310
# from manual_500 import InutNFe_310, RetInutNFe_310, ProcInutNFe_310
# from manual_500 import ConsSitNFe_310, RetConsSitNFe_310, ConsCad_310, RetConsCad_310
# from manual_500 import ConsStatServ_310, RetConsStatServ_310
# from manual_500 import EnvEventoCCe_310, RetEnvEventoCCe_310, ProcEventoNFeCCe_310

#
# Manifesto destinatario
#
# from manifestacao_destinatario import SOAPEnvio_manifest, SOAPRetorno_manifest

#
# DANFE
#
# from danfe.danferetrato import *
import pytz
import tempfile

class ProcessoNFSe(object):
    def __init__(self, webservice=0, envio=None, resposta=None):
        self.webservice = webservice
        self.envio = envio
        self.resposta = resposta


class ProcessadorNFSe(object):
    logger = logging.getLogger('ACTCON-NFSE')  # Registro de log da classe

    def __init__(self):
        self.ambiente = 2
        self.estado = 'MG' # trocar depois
        self.cidade = IBGE_SETE_LAGOAS # por enquanto somente sete lagoas
        self.versao = u'2.02'
        self.certificado = Certificado()
        self.caminho = u''
        self.salvar_arquivos = True
        self.contingencia = False
        self.danfe = DANFE()
        self.caminho_temporario = u'/tmp'
        self.processos = list()
        self._servidor = u''
        self._url = u''
        self._soap_envio = None
        self._soap_retorno = None

    def _conectar_servico(self, servico, envio, resposta):
        self.logger.info(u'>> %s-%s v-%s' % (
            self.ambiente, u'Producao' if self.ambiente == 1 else u'Homologacao', self.versao))
        # webservice = ws_nfse.ESTADO_WS[self.contingencia or self.estado][self.ambiente][servico]
        webservice = ws_nfse.CIDADE_WS.get(self.cidade).get(self.ambiente).get(servico)
        # self.logger.info(self.contingencia or u'>> %s/%s' % (self.estado, UF_CODIGO[self.estado]))
        map(lambda m: self.logger.info(u'>> %s: %s' % m), webservice.items())

        # if servico == WS_NFE_CONSULTA_DESTINATARIO:
        #     self._soap_envio = SOAPEnvio_manifest()
        #     self._soap_retorno = SOAPRetorno_manifest()
        # else:
        self._soap_envio = SOAPEnvio()
        self._soap_retorno = SOAPRetorno()
        # Envio
        self._soap_envio.webservice = webservice['webservice']
        self._soap_envio.metodo = webservice['metodo']
        self._soap_envio.namespace = webservice['namespace']
        self._soap_envio.envio = envio

        # Resposta
        self._soap_retorno.webservice = webservice['webservice']
        self._soap_retorno.metodo = webservice['metodo']
        self._soap_retorno.resposta = resposta

        # Servico
        self._servidor = webservice['servidor']
        self._url = webservice['url']

        # Salva o certificado e a chave privada para uso na conexão HTTPS
        # Salvamos como um arquivo de nome aleatório para evitar o conflito
        # de uso de vários certificados e chaves diferentes na mesma máquina
        # ao mesmo tempo
        self.certificado.prepara_certificado_arquivo_pfx()

        # Verifica vencimento do certificado
        hoje = datetime.now(timezone('UTC')).astimezone(timezone('Brazil/East'))
        validade = self.certificado.data_fim_validade
        if validade.strftime('%Y%m%d') < hoje.strftime('%Y%m%d'):
            error = u'Certificado digital com data expirada: %s ' % validade.strftime('%d/%m/%Y')
            self.logger.critical(error)
            self._soap_retorno.resposta.cStat.valor = u'999'
            self._soap_retorno.resposta.xMotivo.valor = error
            self._soap_retorno.resposta.cUF.valor = self._soap_envio.cUF
            self._soap_retorno.resposta.tpAmb.valor = self.ambiente

            return

        nome_arq_chave = tempfile.NamedTemporaryFile('w')
        nome_arq_chave.write(self.certificado.chave)
        nome_arq_chave.flush()
        nome_arq_certificado = tempfile.NamedTemporaryFile('w')
        nome_arq_certificado.write(self.certificado.certificado)
        nome_arq_certificado.flush()
        nome_arq_cadeia_cert = file(os.path.dirname(
            os.path.abspath(__file__)) + '/../../xml_sped/cadeia-certificadora/cadeia.pem')
        try:
            con = HTTPSSignedConnection(self._servidor, key_file=nome_arq_chave.name,
                                        cert_file=nome_arq_certificado.name,
                                        ca_file=nome_arq_cadeia_cert.name)
            request_url = u'' + os.path.join('/', self._url)
            request_body = self._soap_envio.xml.encode(u'utf-8')
            request_header = self._soap_envio.header
            try:
                con.request('POST', request_url, body=request_body, headers=request_header)
            except Exception as error:
                self.logger.error(u'<<< erro conexao %s >>>' % error)
                self._soap_retorno.resposta.status = 'Erro'
                self._soap_retorno.resposta.reason = error
            else:
                resp = con.getresponse()

                # Dados da resposta salvos para possível debug
                self._soap_retorno.resposta.version = resp.version
                self._soap_retorno.resposta.status = resp.status
                self._soap_retorno.resposta.reason = unicode(resp.reason.decode('utf-8'))
                self._soap_retorno.resposta.msg = resp.msg
                self._soap_retorno.resposta.original = unicode(resp.read().decode('utf-8'))
                self.logger.info(u'>> URL do servico: %s' % os.path.join(self._servidor, self._url))
                self.logger.info(u'>> Metodo da requisição: POST')
                self.logger.info(u'>> URL da requisição: %s' % request_url)
                self.logger.info(u'>> Cabecalho da requisicao: %s' % request_header)
                self.logger.info(u'>> XML envio: %s' % request_body)

                # Retorno da SEFAZ
                self._soap_retorno.xml = self._soap_retorno.resposta.original
                self.logger.info(u'<< Status: %s-%s' % (self._soap_retorno.resposta.status,
                                                        self._soap_retorno.resposta.reason))
                self.logger.info(u'<< XML resposta: %s' % self._soap_retorno.resposta.original)
                self.logger.info(u'<< Mensagem servidor: %s' % self._soap_retorno.resposta.msg)
            con.close()
        except Exception as error:
            self.logger.error(u'<<< erro conexao %s >>>' % error)
            self._soap_retorno.resposta.status = 'Erro'
            self._soap_retorno.resposta.reason = error

        # Apagamos os arquivos do certificado e o da chave privada, para evitar
        # um potencial risco de segurança; muito embora o uso da chave privada
        # para assinatura exija o uso da senha, pode haver serviços que exijam
        # apenas o uso do certificado para validar a identidade, independente
        # da existência de assinatura digital
        nome_arq_chave.close()
        nome_arq_certificado.close()

    def enviar_lote(self, lista_nfe):
        arquivos = list()
        envio = EnviNFe_310()
        resposta = RetEnviNFe_310()
        processo = ProcessoNFSe(WS_NFE_AUTORIZACAO, envio, resposta)

        # Vamos assinar e validar todas as NF-e antes da transmissao evitando rejeicao na SEFAZ por
        # incorrecao no "schema" dos arquivos
        for nfe in lista_nfe if isinstance(lista_nfe, list) else [lista_nfe]:
            self.certificado.assina_xmlnfe(nfe)
            nfe.validar()
            arquivo_nome = nfe.chave + u'-nfe-cert.xml'
            arquivo = nfe.xml.encode('utf-8')
            arquivos.append((arquivo_nome, arquivo))

        envio.NFe = lista_nfe
        envio.idLote.valor = unicode(self.ambiente) + datetime.now().strftime('%Y%m%d%H%M%S')
        envio.validar()
        arquivo_nome = unicode(envio.idLote.valor) + u'-env-lot.xml'
        arquivo = envio.xml.encode('utf-8')
        arquivos.append((arquivo_nome, arquivo))
        self.logger.info(u'*** enviar lote de notas fiscais ***')
        self._conectar_servico(WS_NFE_AUTORIZACAO, envio, resposta)
        arquivo_nome = unicode(envio.idLote.valor)
        if resposta.cStat.valor == u'103':
            arquivo_nome += u'-rec.xml'
        else:
            arquivo_nome += u'-rej.xml'
        arquivo = resposta.xml.encode('utf-8')
        arquivos.append((arquivo_nome, arquivo))

        return processo, arquivos

    def cancelar_nota(self, chave, numero_protocolo=None, justificativa=None):
        arquivos = list()
        envio = EnvEvento_310()
        resposta = RetEnvEvento_310()
        processo = ProcessoNFSe(WS_NFE_CANCELAMENTO, envio, resposta)
        self.caminho = self.monta_caminho_nfe(chave)
        envio.infEvento.tpAmb.valor = self.ambiente
        envio.infEvento.chNFe.valor = chave
        envio.infEvento.nProt.valor = numero_protocolo
        envio.infEvento.xJust.valor = justificativa
        envio.infEvento.cOrgao.valor = UF_CODIGO[self.estado]
        dt = datetime.now()
        dt = dt.replace(tzinfo=pytz.utc)
        data_hora_tz = datetime.astimezone(dt, pytz.timezone("Brazil/East"))
        data_evento = datetime.strftime(data_hora_tz, u'%Y-%m-%dT%H:%M:%S') + str(data_hora_tz)[-6:]
        envio.infEvento.dhEvento.valor = data_evento
        envio.infEvento.CNPJ.valor = chave[6:20]
        self.certificado.prepara_certificado_arquivo_pfx()
        self.certificado.assina_xmlnfe(envio)
        envio.validar()
        novo_arquivo_nome = unicode(envio.infEvento.chNFe.valor) + u'-ped-can.xml'
        novo_arquivo = envio.xml.encode('utf-8')
        arquivos.append((novo_arquivo_nome, novo_arquivo))
        self.logger.info(u'*** cancelamento de nota fiscal ***')
        self._conectar_servico(WS_NFE_CANCELAMENTO, envio, resposta)

        # Se for autorizado, monta o processo de cancelamento
        if resposta.cStat.valor == u'128':
            processo_cancelamento_nfe = ProcEventoNFe_310()
            processo_cancelamento_nfe.envEvento = envio
            processo_cancelamento_nfe.retEnvEvento = resposta
            processo_cancelamento_nfe.validar()
            processo.processo_cancelamento_nfe = processo_cancelamento_nfe
            novo_arquivo_nome = unicode(envio.infEvento.chNFe.valor) + u'-can-pro.xml'

            # Cancelamento autorizado
            if resposta.retEvento.infEvento.cStat.valor == u'135':
                novo_arquivo_nome += u'-can-aut.xml'
            else:
                novo_arquivo_nome += u'-can-rej.xml'

            novo_arquivo = resposta.xml.encode('utf-8')
            arquivos.append((novo_arquivo_nome, novo_arquivo))

            # Se for autorizado, monta o processo de cancelamento
            if resposta.retEvento.infEvento.cStat.valor == u'135':
                # Estranhamente, o nome desse arquivo, pelo manual, deve ser chave-can.xml
                novo_arquivo_nome = unicode(envio.infEvento.chNFe.valor) + u'-can.xml'
                novo_arquivo = processo_cancelamento_nfe.xml.encode('utf-8')
                arquivos.append((novo_arquivo_nome, novo_arquivo))

        return processo, arquivos


    def processar_notas(self, xml):
        self.processos = OrderedDict()
        arquivos = list()
        # processo, novos_arquivos = self.consultar_servico()
        envio = EnviarLoteRpsSincronoEnvio()
        envio.xml = xml
        # for rps in envio.LoteRps.Rps:
        #     self.certificado.prepara_certificado_arquivo_pfx()
        #     self.certificado.assina_xmlnfe(rps, 'Rps')

        self.certificado.prepara_certificado_arquivo_pfx()
        self.certificado.assina_xmlnfe(envio, 'EnviarLoteRpsSincronoEnvio')
        envio.validar()
        resposta = EnviarLoteRpsSincronoResposta()
        self._conectar_servico(RECEPCIONAR_LOTE_RPS_SINCRONO_REQUEST, envio, resposta)
        arquivos.extend(novos_arquivos)
        if self.processo.resposta.cStat.valor == u'107':
            self.logger.info(u'*** montagem do lote de notas fiscais ***')
            for nfe in lista_nfe if isinstance(lista_nfe, list) else [lista_nfe]:
                self.logger.info(u'%s=> %s' % (lista_nfe.index(nfe) + 1, nfe.infNFe.Id.valor))
                nfe.monta_chave()
            self.processo, novos_arquivos = self.enviar_lote(lista_nfe)
            if self.processo.resposta.cStat.valor == u'103':
                arquivos.extend(novos_arquivos)

                # Espere o processamento antes de consultar o recibo
                time.sleep(self.processo.resposta.infRec.tMed.valor * 3)
                self.processo, novos_arquivos = self.consultar_recibo(
                    self.processo.resposta.infRec.nRec.valor)
                arquivos.extend(novos_arquivos)

        return self.processo, arquivos

    def monta_caminho_nfe(self, chave):
        caminho = self.caminho_temporario
        if self.ambiente == 1:
            caminho = os.path.join(caminho, 'producao/')
        else:
            caminho = os.path.join(caminho, 'homologacao/')
        data = u'20' + chave[2:4] + u'-' + chave[4:6]
        serie = chave[22:25]
        numero = chave[25:34]
        caminho = os.path.join(caminho, data + u'/')
        caminho = os.path.join(caminho, serie + u'-' + numero + u'/')
        try:
            os.makedirs(caminho)
        except:
            pass
        return caminho

class DANFE(object):
    def __init__(self):
        self.imprime_canhoto = True
        self.imprime_local_retirada = True
        self.imprime_local_entrega = True
        self.imprime_fatura = True
        self.imprime_duplicatas = True
        self.imprime_issqn = True
        self.caminho = u'/tmp'
        self.salvar_arquivo = False
        self.NFe = None
        self.protNFe = None
        self.retCancNFe = None
        self.danfe = None
        self.versao = u'2.02'
        self.obs_impressao = u'DANFE gerado em %(now:%d/%m/%Y as %H:%M:%S)s'
        self.nome_sistema = u''
        self.site = u''
        self.logo = u''
        self.leiaute_logo_vertical = False
        self.dados_emitente = list()

    def gerar_danfe(self):
        if self.NFe is None:
            raise ValueError(u'Não é possível gerar um DANFE sem a informação de uma NF-e')
        if self.protNFe is None:
            self.protNFe = ProtNFe_310()
        if self.retCancNFe is None:
            self.retCancNFe = RetCancNFe_310()

        # Prepara o queryset para impressão
        self.NFe.monta_chave()
        self.NFe.monta_dados_contingencia_fsda()
        self.NFe.site = self.site

        for detalhe in self.NFe.infNFe.det:
            detalhe.NFe = self.NFe
            detalhe.protNFe = self.protNFe
            detalhe.retCancNFe = self.retCancNFe

        # Prepara as bandas de impressão para cada formato
        if self.NFe.infNFe.ide.tpImp.valor == 2:
            # raise ValueError(u'DANFE em formato paisagem ainda não implementado')
            # Como o formato paisagem ainda nao foi implementado, o DANFE sera gerado no formato
            # retrato
            self.NFe.infNFe.ide.tpImp.valor = 1
            self.danfe = DANFERetrato(versao=self.versao)
            self.danfe.queryset = self.NFe.infNFe.det
        else:
            self.danfe = DANFERetrato(versao=self.versao)
            self.danfe.queryset = self.NFe.infNFe.det

        if self.imprime_canhoto:
            self.danfe.band_page_header = self.danfe.canhoto
            self.danfe.band_page_header.child_bands = []
            self.danfe.band_page_header.child_bands.append(self.danfe.remetente)
        else:
            self.danfe.band_page_header = self.danfe.remetente
            self.danfe.band_page_header.child_bands = []

        # Emissão para simples conferência / sem protocolo de autorização
        if not self.protNFe.infProt.nProt.valor:
            self.danfe.remetente.campo_variavel_conferencia()
        elif self.protNFe.infProt.cStat.valor == u'110':  # NF-e denegada
            self.danfe.remetente.campo_variavel_denegacao()
            self.danfe.remetente.obs_denegacao()
        elif self.NFe.infNFe.ide.tpEmis.valor in (2, 5,):  # Emissão em contingência com FS ou FSDA
            self.danfe.remetente.campo_variavel_contingencia_fsda()
            self.danfe.remetente.obs_contingencia_normal_scan()
        elif self.NFe.infNFe.ide.tpEmis.valor == 4:  # Emissão em contingência com DPEC
            self.danfe.remetente.campo_variavel_contingencia_dpec()
            self.danfe.remetente.obs_contingencia_dpec()
        else:  # Emissão normal ou contingência SCAN, SVC-AN e SVC-RS
            self.danfe.remetente.campo_variavel_normal()
            # Contingência SCAN,SVC-AN e SVC-RS
            if self.NFe.infNFe.ide.tpEmis.valor in (3, 6, 7):
                self.danfe.remetente.obs_contingencia_normal_scan()

        # A NF-e foi cancelada, no DANFE imprimir o "carimbo" de cancelamento
        if self.retCancNFe.infCanc.tpEvento.valor:
            self.danfe.remetente.obs_cancelamento()

        # Observação de ausência de valor fiscal
        # se não houver protocolo ou se o ambiente for de homologação
        if (not self.protNFe.infProt.nProt.valor) or self.NFe.infNFe.ide.tpAmb.valor == 2:
            self.danfe.remetente.obs_sem_valor_fiscal()

        self.danfe.band_page_header.child_bands.append(self.danfe.destinatario)
        if self.imprime_local_retirada and len(self.NFe.infNFe.retirada.xml):
            self.danfe.band_page_header.child_bands.append(self.danfe.local_retirada)
        if self.imprime_local_entrega and len(self.NFe.infNFe.entrega.xml):
            self.danfe.band_page_header.child_bands.append(self.danfe.local_entrega)
        if self.imprime_fatura:
            # Outros pagamentos
            if self.NFe.infNFe.ide.indPag.valor == 2:
                self.danfe.band_page_header.child_bands.append(self.danfe.fatura_outras)
            # Pagamento a prazo
            elif (self.NFe.infNFe.ide.indPag.valor == 1) or \
                    (len(self.NFe.infNFe.cobr.dup) > 1) or \
                    ((len(self.NFe.infNFe.cobr.dup) == 1) and
                         (self.NFe.infNFe.cobr.dup[0].dVenc.xml > self.NFe.infNFe.ide.dEmi.xml)):
                if self.imprime_duplicatas:
                    self.danfe.fatura_a_prazo.elements.append(self.danfe.duplicatas)
                self.danfe.band_page_header.child_bands.append(self.danfe.fatura_a_prazo)
            else:  # Pagamentos a vista
                self.danfe.band_page_header.child_bands.append(self.danfe.fatura_a_vista)
        self.danfe.band_page_header.child_bands.append(self.danfe.calculo_imposto)
        self.danfe.band_page_header.child_bands.append(self.danfe.transporte)
        self.danfe.band_page_header.child_bands.append(self.danfe.cab_produto)
        if self.imprime_issqn and len(self.NFe.infNFe.total.ISSQNTot.xml):
            self.danfe.band_page_footer = self.danfe.iss
        else:
            self.danfe.band_page_footer = self.danfe.dados_adicionais
        self.danfe.band_detail = self.danfe.det_produto

        # Observação de impressão
        if self.nome_sistema:
            self.danfe.ObsImpressao.expression = self.nome_sistema + u' - ' + self.obs_impressao
        else:
            self.danfe.ObsImpressao.expression = self.obs_impressao

        # Quadro do emitente
        if self.dados_emitente:
            self.danfe.remetente.monta_quadro_emitente(self.dados_emitente)
        else:  # Sem logotipo
            if not self.logo:
                self.danfe.remetente.monta_quadro_emitente(
                    self.danfe.remetente.dados_emitente_sem_logo())
            elif self.leiaute_logo_vertical:  # Logotipo na vertical
                self.danfe.remetente.monta_quadro_emitente(
                    self.danfe.remetente.dados_emitente_logo_vertical(self.logo))
            else:  # Logotipo na horizontal
                self.danfe.remetente.monta_quadro_emitente(
                    self.danfe.remetente.dados_emitente_logo_horizontal(self.logo))

        if self.salvar_arquivo:
            nome_arq = self.caminho + self.NFe.chave + u'.pdf'
            type(self.danfe.generate_by(PDFGenerator, filename=nome_arq))

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
